@@ -3,34 +3,49 @@
 # Name: Editra.py                                                             #
 # Purpose: Implements Editras App object and the Main method                  #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
 # License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE:  Editra.py                                                         #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-#                                                                          #
-# SUMMARY:                                                                 #
-#   This module defines the Editra Application object and the Main method  #
-# for running Editra.                                                      #
-#                                                                          #
-#--------------------------------------------------------------------------#
+FILE:  Editra.py
+AUTHOR: Cody Precord
+LANGUAGE: Python
+
+SUMMARY:
+This module defines the Editra Application object and the Main method
+for running Editra.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 51327 2008-01-22 08:33:38Z CJP $"
-__revision__ = "$Revision: 51327 $"
+__svnid__ = "$Id: Editra.py 52302 2008-03-04 08:04:48Z CJP $"
+__revision__ = "$Revision: 52302 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+import time
 import getopt
-import gettext
 import wx
+
+# Due to some methods that were added in 2.8.3 being used in a large number
+# of places Editra has become incompatable with wxPython 2.8.1.1 and earlier.
+# TODO: add a message dialog to display this, or look into the cause of the
+#       issues of using wxversion on windows.
+if not hasattr(sys, 'frozen') and wx.VERSION < (2, 8, 3, ''):
+    print "VersionError: Editra requires wxPython 2.8.3 or higher"
+    print "              Your version is %s" % wx.VERSION_STRING
+
+# Try and import a system installed version of pkg_resources else fallback to
+# the one bundled with Editra's source.
+try:
+    from pkg_resources import resource_filename
+except ImportError:
+    from extern.pkg_resources import resource_filename
+
+# Editra Libraries
 import ed_glob
 import ed_i18n
 import profiler
@@ -39,11 +54,14 @@ import dev_tool
 import ed_main
 import ed_art
 import ed_txt
+import ed_event
+import updater
 import plugin
 import extern.events as events
 
 #--------------------------------------------------------------------------#
 # Global Variables
+ID_UPDATE_CHECK = wx.NewId()
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -65,11 +83,34 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._log = dev_tool.DEBUGP
         self._lock = False
         self._windows = dict()
+
+        # Setup Locale
+        self.locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
+        if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
+            self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
+            self.locale.AddCatalog(ed_glob.PROG_NAME)
+        else:
+            del self.locale
+            self.locale = None
+
+        # Setup Plugins after locale as they may have resource that need to
+        # be loaded.
         self._pluginmgr = plugin.PluginManager()
 
         self._log("[app][info] Registering Editra's ArtProvider")
         wx.ArtProvider.PushProvider(ed_art.EditraArt())
 
+    def AddMessageCatalog(self, name, path):
+        """Add a catalog lookup path to the app
+        @param name: name of catalog (i.e 'projects')
+        @param path: catalog lookup path
+
+        """
+        if self.locale is not None:
+            path = resource_filename(path, 'locale')
+            self.locale.AddCatalogLookupPathPrefix(path)
+            self.locale.AddCatalog(name)
+
     def OnInit(self):
         """Initialize the Editor
         @note: this gets called before __init__
@@ -87,7 +128,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self.Bind(wx.EVT_ACTIVATE_APP, self.OnActivate)
         self.Bind(wx.EVT_MENU, self.OnNewWindow, id=ed_glob.ID_NEW_WINDOW)
         self.Bind(wx.EVT_MENU, self.OnCloseWindow)
- 
+        self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
+
         return True
 
     def Exit(self, force=False):
@@ -101,6 +143,14 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         if not self._lock or force:
             wx.App.Exit(self)
 
+    def GetLocaleObject(self):
+        """Get the locale object owned by this app. Use this method to add
+        extra catalogs for lookup.
+        @return: wx.Locale or None
+
+        """
+        return self.locale
+
     def GetLog(self):
         """Returns the logging function used by the app
         @return: the logging function of this program instance
@@ -112,7 +162,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """Returns reference to the instance of the MainWindow
         that is running if available, and None if not.
         @return: the L{MainWindow} of this app if it is open
-        
+
         """
         self._log("[app][warn] Editra::GetMainWindow is deprecated")
         for window in self._windows:
@@ -144,7 +194,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
     def GetMainWindows(self):
         """Returns a list of all open main windows
         @return: list of L{MainWindow} instances of this app (list may be empty)
-        
+
         """
         mainw = list()
         for window in self._windows:
@@ -202,7 +252,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         running.
         @param filename: file path string
         @postcondition: if L{MainWindow} is open file will be opened in notebook
-        
+
         """
         window = self.GetTopWindow()
         if getattr(window, '__name__', '') == "MainWindow":
@@ -288,7 +338,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         """
         frame = ed_main.MainWindow(None, wx.ID_ANY,
-                                   profiler.Profile_Get('WSIZE'), 
+                                   profiler.Profile_Get('WSIZE'),
                                    ed_glob.PROG_NAME)
         if caller:
             pos = caller.GetPosition()
@@ -299,21 +349,44 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         if isinstance(fname, basestring) and fname != u'':
             frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname)
         frame.Show(True)
-        
+
         # Ensure frame gets an Activate event when shown
         # this doesn't happen automatically on windows
         if wx.Platform == '__WXMSW__':
             wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
 
+    def OnNotify(self, evt):
+        """Handle notification events
+        @param evt: L{ed_event.NotifyEvent}
+
+        """
+        e_val = evt.GetValue()
+        if evt.GetId() == ID_UPDATE_CHECK and \
+           isinstance(e_val, tuple) and e_val[0]:
+            mdlg = wx.MessageDialog(self.GetActiveWindow(),
+                                    _("An updated version of Editra is available\n"
+                                      "Would you like to download Editra %s now?") %\
+                                      e_val[1], _("Update Available"),
+                                    wx.YES_NO|wx.YES_DEFAULT|wx.CENTER|wx.ICON_INFORMATION)
+            if mdlg.ShowModal() == wx.ID_YES:
+                dl_dlg = updater.DownloadDialog(None, wx.ID_ANY,
+                                                _("Downloading Update"))
+                dp_sz = wx.GetDisplaySize()
+                dl_dlg.SetPosition(((dp_sz[0] - (dl_dlg.GetSize()[0] + 5)), 25))
+                dl_dlg.Show()
+            mdlg.Destroy()
+        else:
+            evt.Skip()
+
     def RegisterWindow(self, name, window, can_lock=False):
         """Registers winows with the app. The name should be the
         repr of window. The can_lock parameter is a boolean stating
-        whether the window can keep the main app running after the 
+        whether the window can keep the main app running after the
         main frame has exited.
         @param name: name of window
         @param window: reference to window object
         @keyword can_lock: whether window can lock exit or not
-        
+
         """
         self._windows[name] = (window, can_lock)
 
@@ -336,12 +409,12 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def UnRegisterWindow(self, name):
         """Unregisters a named window with the app if the window
-        was the top window and if other windows that can lock are 
-        registered in the window stack it will promote the next one 
+        was the top window and if other windows that can lock are
+        registered in the window stack it will promote the next one
         it finds to be the top window. If no windows that fit this
         criteria are found it will close the application.
         @param name: name of window to unregister
-        
+
         """
         if self._windows.has_key(name):
             self._windows.pop(name)
@@ -378,7 +451,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         a call to RegisterWindow for this function to have any
         real usefullness.
         @param winname: name of window to query
-        
+
         """
         if self._windows.has_key(winname):
             return self._windows[winname][1]
@@ -408,11 +481,6 @@ def InitConfig():
             profiler.Profile().Update()
 
             #---- Temporary Profile Adaptions ----#
-            ## Force some default values to be set on an upgrade
-            if wx.Platform == '__WXGTK__':
-                profiler.Profile_Set('ICONS', 'Default')
-            else:
-                profiler.Profile_Set('ICONS', 'Tango')
 
             # GUI_DEBUG mode removed in 0.2.5
             mode = profiler.Profile_Get('MODE')
@@ -453,7 +521,7 @@ def InitConfig():
     ed_glob.CONFIG['STYLES_DIR'] = util.ResolvConfigDir("styles")
     ed_glob.CONFIG['SYS_PLUGIN_DIR'] = util.ResolvConfigDir("plugins", True)
     ed_glob.CONFIG['SYS_STYLES_DIR'] = util.ResolvConfigDir("styles", True)
-    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join("tests", 
+    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join("tests",
                                                                    "syntax"),
                                                                    True)
     if not util.HasConfigDir("cache"):
@@ -471,7 +539,7 @@ def Main():
 
     """
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "dhv", 
+        opts, args = getopt.getopt(sys.argv[1:], "dhv",
                                    ['debug', 'help', 'version'])
     except getopt.GetoptError, msg:
         dev_tool.DEBUGP("[main][err] %s" % str(msg))
@@ -506,23 +574,10 @@ def Main():
     # We are ready to run so fire up the config and launch the app
     profile_updated = InitConfig()
 
-    # 1. Create Application
+    # Create Application
     dev_tool.DEBUGP("[main][info] Initializing Application...")
     editra_app = Editra(False)
 
-    # 2. Initialize the Language Settings
-    the_locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
-    if the_locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
-        the_locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
-        the_locale.AddCatalog(ed_glob.PROG_NAME)
-        language = gettext.translation(ed_glob.PROG_NAME, 
-                                       ed_glob.CONFIG['LANG_DIR'],
-                                       [the_locale.GetCanonicalName()], 
-                                       fallback=True)
-        language.install()
-    else:
-        del the_locale
-
     if profile_updated:
         # Make sure window iniliazes to default position
         profiler.Profile_Del('WPOS')
@@ -540,17 +595,17 @@ def Main():
                                  wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
         splash.Show()
 
-    frame = ed_main.MainWindow(None, wx.ID_ANY, profiler.Profile_Get('WSIZE'), 
+    frame = ed_main.MainWindow(None, wx.ID_ANY, profiler.Profile_Get('WSIZE'),
                                ed_glob.PROG_NAME)
     editra_app.RegisterWindow(repr(frame), frame, True)
     editra_app.SetTopWindow(frame)
+    frame.Show(True)
 
     # Load Session Data
     # But not if there are command line args for files to open
     if profiler.Profile_Get('SAVE_SESSION', 'bool', False) and not len(args):
         frame.GetNotebook().LoadSessionFiles()
 
-    frame.Show(True)
     # Unlike wxMac/wxGTK Windows doesn't post an activate event when a window
     # is first shown, so do it manually to make sure all event handlers get
     # pushed.
@@ -560,6 +615,15 @@ def Main():
     if 'splash' in locals():
         splash.Destroy()
 
+    # Do update check, only check if its been more than a day since the last
+    # check
+    tval = sum(time.localtime(time.time())[:3])
+    if profiler.Profile_Get('CHECKUPDATE', default=True) and \
+       tval - profiler.Profile_Get('LASTCHECK', 'int', default=0) > 1:
+        profiler.Profile_Set('LASTCHECK', tval)
+        uthread = updater.UpdateThread(editra_app, ID_UPDATE_CHECK)
+        uthread.start()
+
     for arg in args:
         try:
             arg = os.path.abspath(arg)
