@@ -3,33 +3,32 @@
 # Purpose: Provides the front end interface for autocompletion services for   #
 #          the editor.                                                        #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: autocomp.py                                                        #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-# SUMMARY:                                                                 #
-#    Provides an interface/service for getting autocompletion/calltip data #
-# into an stc control. This is a data provider only it does not do provide #
-# any UI functionality or calls. The user called object from this library  #
-# is intended to be the AutoCompService. This service provides the generic #
-# interface into the various language specific autocomplete services, and  #
-# makes the calls to the other support objects/functions in this library.  #
-#                                                                          #
-#--------------------------------------------------------------------------#
+FILE: autocomp.py
+AUTHOR: Cody Precord
+LANGUAGE: Python
+SUMMARY:
+   Provides an interface/service for getting autocompletion/calltip data
+into an stc control. This is a data provider only it does not do provide
+any UI functionality or calls. The user called object from this library
+is intended to be the AutoCompService. This service provides the generic
+interface into the various language specific autocomplete services, and
+makes the calls to the other support objects/functions in this library.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: autocomp.py 49415 2007-10-25 05:06:57Z CJP $"
-__revision__ = "$Revision: 49415 $"
+__cvsid__ = "$Id: autocomp.py 51603 2008-02-08 14:06:25Z CJP $"
+__revision__ = "$Revision: 51603 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import wx.stc as stc
+
 #--------------------------------------------------------------------------#
 
 class AutoCompService(object):
@@ -59,17 +58,16 @@ class AutoCompService(object):
         else:
             return list()
 
-    def GetAutoCompList(self, command, namespace=None):
+    def GetAutoCompList(self, command):
         """Retrieves the sorted autocomplete list for a command
         @param command: command string to do lookup on
-        @keyword namespace: namespace to use
 
         """
         if self._completer != None:
-            return self._completer.GetAutoCompList(command, namespace)
+            return self._completer.GetAutoCompList(command)
         else:
             return list()
- 
+
     def GetAutoCompStops(self):
         """Returns a string of characters that should cancel
         the autocompletion lookup.
@@ -81,14 +79,13 @@ class AutoCompService(object):
         else:
             return u''
 
-    def GetCallTip(self, command, namespace=None):
+    def GetCallTip(self, command):
         """Returns the calltip string for a command
         @param command: command to get callip for
-        @keyword namespace: namespace to do lookup in
 
         """
         if self._completer != None:
-            return self._completer.GetCallTip(command, namespace)
+            return self._completer.GetCallTip(command)
         else:
             return u''
 
@@ -121,18 +118,4 @@ class AutoCompService(object):
             import pycomp
             self._completer = pycomp.Completer(self._buffer)
         else:
-            pass
-
-    def UpdateNamespace(self, opt=None):
-        """Tells the completer to update its namespace
-        @keyword opt: specific option to pass to completer for updating the
-                      namespace.
-
-        """
-        if hasattr(self._completer, 'UpdateNamespace'):
-            if opt == None:
-                self._completer.UpdateNamespace()
-            else:
-                self._completer.UpdateNamespace(opt)
-        else:
-            pass
+            self._completer = None
