@@ -12,10 +12,14 @@ Editra but are not tied to Editra's framework in anyway.
 
 Controls:
   * PlateButton: Customizable flat button
+  * ControlBox: Custom panel with easy layout and optional mini toolbar like
+                control.
+  * ControlBar: Custom mini toolbar like control used by ControlBox
+  * OutputBuffer: Output display buffer that can be easily used with threads
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: __init__.py 50598 2007-12-09 14:17:49Z CJP $"
-__revision__ = "$Revision: 50598 $"
+__cvsid__ = "$Id: __init__.py 51429 2008-01-29 07:44:37Z CJP $"
+__revision__ = "$Revision: 51429 $"
 
