@@ -13,7 +13,7 @@ This module contains classes that are usefull for displaying output from running
 tasks and processes. The classes are divided into three main catagories, gui
 classes, mixins, and thread classes. All the classes can be used together to
 easily create multithreaded gui display classes without neededing to worry about
-the details and thread saftey of the gui.
+the details and thread safety of the gui.
 
 For example usage of these classes see ed_log and the Editra's Launch plugin
 
@@ -26,6 +26,8 @@ handling.
 
   * Override the ApplyStyles method to do any processing and coloring of the
     text as it is put in the buffer.
+  * Override the DoHotSpotClicked method to handle any actions to take when a
+    hotspot has been clicked in the buffer.
   * Override the DoUpdatesEmpty method to perform any idle processing when no
     new text is waiting to be processed.
 
@@ -49,8 +51,8 @@ L{OutputBuffer} via events.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 51539 2008-02-04 08:02:12Z CJP $"
-__revision__ = "$Revision: 51539 $"
+__svnid__ = "$Id: outbuff.py 52287 2008-03-03 14:12:20Z CJP $"
+__revision__ = "$Revision: 52287 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -72,10 +74,11 @@ OUTPUTBUFF_NAME_STR = u'EditraOutputBuffer'
 THREADEDBUFF_NAME_STR = u'EditraThreadedBuffer'
 
 # Style Codes
-OPB_STYLE_DEFAULT = 0
-OPB_STYLE_INFO    = 1
-OPB_STYLE_WARN    = 2
-OPB_STYLE_ERROR   = 3
+OPB_STYLE_DEFAULT = 0  # Default Black text styling
+OPB_STYLE_INFO    = 1  # Default Blue text styling
+OPB_STYLE_WARN    = 2  # Default Red text styling
+OPB_STYLE_ERROR   = 3  # Default Red/Hotspot text styling
+OPB_STYLE_MAX     = 3  # Highest style byte used by outputbuffer
 
 #--------------------------------------------------------------------------#
 
@@ -111,9 +114,10 @@ class OutputBufferEvent(wx.PyCommandEvent):
 #--------------------------------------------------------------------------#
 
 class OutputBuffer(wx.stc.StyledTextCtrl):
-    """Output buffer to display results. The ouputbuffer is a readonly
-    buffer meant for displaying results from running processes or batch
-    jobs
+    """OutputBuffer is a general purpose output display for showing text. It
+    provides an easy interface for the buffer to interact with multiple threads
+    that may all be sending updates to the buffer at the same time. Methods for
+    styleing and filtering output are also available.
 
     """
     def __init__(self, parent, id=wx.ID_ANY, 
@@ -134,6 +138,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
 
         # Event Handlers
         self.Bind(wx.EVT_TIMER, self.OnTimer)
+        self.Bind(wx.stc.EVT_STC_HOTSPOT_CLICK, self._OnHotSpot)
 
     def __del__(self):
         """Ensure timer is cleaned up when we are deleted"""
@@ -143,6 +148,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
     def __ConfigureSTC(self):
         """Setup the stc to behave/appear as we want it to 
         and define all styles used for giving the output context.
+        @todo: make more of this configurable
 
         """
         self.SetMargins(3, 3)
@@ -150,15 +156,48 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.SetMarginWidth(1, 0)
 
         self.SetLayoutCache(wx.stc.STC_CACHE_DOCUMENT)
+        self.SetUndoCollection(False) # Don't keep undo history
         self.SetReadOnly(True)
+        self.SetCaretWidth(0)
         
         #self.SetEndAtLastLine(False)
         self.SetVisiblePolicy(1, wx.stc.STC_VISIBLE_STRICT)
 
         # Define Styles
-        font = wx.Font(11, wx.FONTFAMILY_MODERN, 
-                       wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL)
+        highlight = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+        self.SetSelBackground(True, highlight)
+        self.__SetupStyles()
+
+    def __PutText(self, txt, ind):
+        """
+        @param txt: String to append
+        @param ind: index in update buffer
+
+        """
+        self._updating.acquire()
+        self.SetReadOnly(False)
+        start = self.GetLength() # Get position new text will start from
+        self.AppendText(txt)
+        self.GotoPos(self.GetLength())
+        self._updates = self._updates[ind:]
+        self.ApplyStyles(start, txt)
+        self.SetReadOnly(True)
+        self._updating.release()
+
+    def __SetupStyles(self, font=None):
+        """Setup the default styles of the text in the buffer
+        @keyword font: wx.Font to use or None to use default
+
+        """
+        if font is None:
+            if wx.Platform == '__WXMAC__':
+                fsize = 11
+            else:
+                fsize = 10
+            font = wx.Font(fsize, wx.FONTFAMILY_MODERN, 
+                           wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL)
         style = (font.GetFaceName(), font.GetPointSize(), "#FFFFFF")
+        wx.stc.StyledTextCtrl.SetFont(self, font)
         
         # Custom Styles
         self.StyleSetSpec(OPB_STYLE_DEFAULT, 
@@ -166,7 +205,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.StyleSetSpec(OPB_STYLE_INFO,
                           "face:%s,size:%d,fore:#0000FF,back:%s" % style)
         self.StyleSetSpec(OPB_STYLE_WARN,
-                          "face:%s,size:%d,fore:#0000FF,back:%s" % style)
+                          "face:%s,size:%d,fore:#FF0000,back:%s" % style)
         self.StyleSetSpec(OPB_STYLE_ERROR, 
                           "face:%s,size:%d,fore:#FF0000,back:%s" % style)
         self.StyleSetHotSpot(OPB_STYLE_ERROR, True)
@@ -178,25 +217,15 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
                           "face:%s,size:%d,fore:#000000,back:%s" % style)
         self.Colourise(0, -1)
 
-    def __PutText(self, txt, ind):
-        """
-        @param txt: String to append
-        @param ind: index in update buffer
-
-        """
-        self._updating.acquire()
-        self.SetReadOnly(False)
-        start = self.GetLength()
-        self.AppendText(txt)
-        self.GotoPos(self.GetLength())
-        self._updates = self._updates[ind:]
-        self.ApplyStyles(start, txt)
-        self.SetReadOnly(True)
-        self._updating.release()
+    def _OnHotSpot(self, evt):
+        """Handle hotspot clicks"""
+        pos = evt.GetPosition()
+        self.DoHotSpotClicked(pos, self.LineFromPosition(pos))
 
     #---- Public Member Functions ----#
     def AppendUpdate(self, value):
-        """Buffer output before adding to window
+        """Buffer output before adding to window. This method can safely be
+        called from non gui threads to add updates to the buffer. 
         @param value: update string to append to stack
 
         """
@@ -218,8 +247,18 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
     def Clear(self):
         """Clear the Buffer"""
         self.SetReadOnly(False)
-        self.SetText('')
-        self.SetReadOnly(False)
+        self.ClearAll()
+        self.EmptyUndoBuffer()
+        self.SetReadOnly(True)
+
+    def DoHotSpotClicked(self, pos, line):
+        """Action to perform when a hotspot region is clicked in the buffer.
+        Override this function to provide handling of hotspots.
+        @param pos: Position in buffer of where the click occurred.
+        @param line: Line in which the click occurred (zero based index)
+
+        """
+        pass
 
     def DoUpdatesEmpty(self):
         """Called when update stack is empty
@@ -251,6 +290,13 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         else:
             pass
 
+    def SetFont(self, font):
+        """Set the font used by all text in the buffer
+        @param font: wxFont
+
+        """
+        self.__SetupStyles(font)
+
     def SetText(self, text):
         """Set the text that is shown in the buffer
         @param text: text string to set as buffers current value
@@ -336,7 +382,9 @@ class ProcessBufferMixin:
         pass
 
     def SetUpdateInterval(self, value):
-        """Set the rate at which the buffer outputs update messages
+        """Set the rate at which the buffer outputs update messages. Set to
+        a higher number if the process outputs large amounts of text at a very
+        high rate.
         @param value: rate in milliseconds to do updates on
 
         """
@@ -370,7 +418,7 @@ class ProcessThread(threading.Thread):
         threading.Thread.__init__(self)
 
         if isinstance(args, list):
-            args = ' '.join([arg.strip() for arg in args])
+            args = u' '.join([arg.strip() for arg in args])
 
         # Attributes
         self.abort = False          # Abort Process
@@ -439,17 +487,17 @@ class ProcessThread(threading.Thread):
         @note: overridden from Thread
 
         """
-        command = ' '.join([item.strip() for item in [self._cmd['cmd'],
-                                                      self._cmd['file'],
-                                                      self._cmd['args']]])
+        command = u' '.join([item.strip() for item in [self._cmd['cmd'],
+                                                       self._cmd['file'],
+                                                       self._cmd['args']]])
         
         proc = subprocess.Popen(command.strip(), stdout=subprocess.PIPE,
                                 stderr=subprocess.STDOUT, shell=True,
                                 cwd=self._cwd, env=self._env)
 
         evt = OutputBufferEvent(edEVT_PROCESS_START,
-                             self._parent.GetId(),
-                             command.strip())
+                                self._parent.GetId(),
+                                command.strip())
         wx.CallAfter(wx.PostEvent, self._parent, evt)
 
         # Read from stdout while there is output from process
@@ -486,7 +534,7 @@ class ProcessThread(threading.Thread):
 
         """
         if isinstance(args, list):
-            ' '.join(item.strip() for item in args)
+            u' '.join(item.strip() for item in args)
         self._cmd['args'] = args.strip()
 
     def SetCommand(self, cmd):
