@@ -21,8 +21,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 51394 2008-01-27 04:09:59Z CJP $"
-__revision__ = "$Revision: 51394 $"
+__svnid__ = "$Id: ed_glob.py 52188 2008-02-29 06:19:49Z CJP $"
+__revision__ = "$Revision: 52188 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN', 
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL', 
@@ -44,7 +44,8 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 'ID_MACRO_STOP',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
             'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
-            'ID_CLOSE_WINDOW', 'ID_USE_SOFTTABS', 'ID_DUP_LINE'
+            'ID_CLOSE_WINDOW', 'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
+            'I18N_PAGE'
 ]
 
 #---- Project Info ----#
@@ -132,6 +133,7 @@ ID_PREF          = wx.ID_PREFERENCES
 ID_PREF_LANG     = wx.NewId()
 ID_PREF_AALIAS   = wx.NewId()
 ID_PREF_CHKMOD   = wx.NewId()
+ID_PREF_CHKUPDATE = wx.NewId()
 ID_PREF_DLEXER   = wx.NewId()
 ID_PREF_EDGE     = wx.NewId()
 ID_PREF_SYNTHEME = wx.NewId()
@@ -213,6 +215,7 @@ ID_RTF_GEN       = wx.NewId()
 ID_ABOUT         = wx.ID_ABOUT
 ID_HOMEPAGE      = wx.ID_HOME
 ID_DOCUMENTATION = wx.NewId()
+ID_TRANSLATE     = wx.NewId()
 ID_CONTACT       = wx.NewId()
 
 # Misc IDs
@@ -254,6 +257,7 @@ ID_2_PROF = {
              ID_AUTOINDENT        : 'AUTO_INDENT',
              ID_BRACKETHL         : 'BRACKETHL',
              ID_PREF_CHKMOD       : 'CHECKMOD',
+             ID_PREF_CHKUPDATE    : 'CHECKUPDATE',
              ID_FOLDING           : 'CODE_FOLD',
              ID_PERSPECTIVES      : 'DEFAULT_VIEW',
              ID_KWHELPER          : 'KWHELPER',
