@@ -16,20 +16,25 @@ displaying a LogViewer in the Shelf.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_log.py 51577 2008-02-07 12:12:36Z CJP $"
-__revision__ = "$Revision: 51577 $"
+__svnid__ = "$Id: ed_log.py 52189 2008-02-29 08:01:50Z CJP $"
+__revision__ = "$Revision: 52189 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
+import re
 import wx
+
+# Editra Libraries
 import ed_msg
 import eclib.outbuff as outbuff
 import eclib.ctrlbox as ctrlbox
 import eclib.platebtn as platebtn
 import iface
 import plugin
+from profiler import Profile_Get
 import ed_glob
+import ed_txt
 
 #-----------------------------------------------------------------------------#
 # Globals
@@ -65,7 +70,7 @@ class EdLogViewer(plugin.Plugin):
         @param menu: the menu items parent menu
 
         """
-        return wx.MenuItem(menu, self.ID_LOGGER, _(self.__name__), 
+        return wx.MenuItem(menu, self.ID_LOGGER, _("Editra Log"),
                            _("View Editra's console log"))
 
     def GetName(self):
@@ -143,12 +148,14 @@ class LogViewer(ctrlbox.ControlBox):
             self._srcfilter.SetSelection(0)
 
 #-----------------------------------------------------------------------------#
-
 class LogBuffer(outbuff.OutputBuffer):
     """Buffer for displaying log messages that are sent on Editra's
     log channel.
 
     """
+    RE_WARN_MSG = re.compile(r'\[err\]|\[error\]|\[warn\]')
+    ERROR_STYLE = outbuff.OPB_STYLE_MAX + 1
+
     def __init__(self, parent):
         outbuff.OutputBuffer.__init__(self, parent)
 
@@ -156,6 +163,15 @@ class LogBuffer(outbuff.OutputBuffer):
         self._filter = SHOW_ALL_MSG
         self._srcs = list()
 
+        # Setup
+        font = Profile_Get('FONT1', 'font', wx.Font(11, wx.FONTFAMILY_MODERN, 
+                                                    wx.FONTSTYLE_NORMAL, 
+                                                    wx.FONTWEIGHT_NORMAL))
+        self.SetFont(font)
+        style = (font.GetFaceName(), font.GetPointSize(), "#FF0000")
+        self.StyleSetSpec(LogBuffer.ERROR_STYLE,
+                          "face:%s,size:%d,fore:#FFFFFF,back:%s" % style)
+
         # Subscribe to Editra's Log
         ed_msg.Subscribe(self.UpdateLog, ed_msg.EDMSG_LOG_ALL)
 
@@ -176,6 +192,20 @@ class LogBuffer(outbuff.OutputBuffer):
         else:
             pass
 
+    def ApplyStyles(self, start, txt):
+        """Apply coloring to error and warning messages
+        @note: overridden from L{outbuff.OutputBuffer}
+        @param start: Start position of text that needs styling in the buffer
+        @param txt: The string of text that starts at the start position in the
+                    buffer.
+
+        """
+        for group in LogBuffer.RE_WARN_MSG.finditer(txt):
+            sty_s = start + group.start()
+            sty_e = start + group.end()
+            self.StartStyling(sty_s, 0xff)
+            self.SetStyling(sty_e - sty_s, self.ERROR_STYLE)
+
     def SetFilter(self, src):
         """Set the level of what is shown in the display
         @param src: Only show messages from src
@@ -204,7 +234,7 @@ class LogBuffer(outbuff.OutputBuffer):
         logmsg = msg.GetData()
         self.AddFilter(logmsg.Origin)
         if self._filter == SHOW_ALL_MSG:
-            self.AppendUpdate(str(logmsg) + os.linesep)
+            self.AppendUpdate(unicode(logmsg) + os.linesep)
         elif self._filter == logmsg.Origin:
             msg = "[%s][%s]%s" % (logmsg.ClockTime, logmsg.Type, logmsg.Value)
             self.AppendUpdate(msg + os.linesep)
