@@ -7,31 +7,29 @@
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: ed_main.py                                                         #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-#                                                                          #
-# SUMMARY:                                                                 #
-#  This module provides the class for the main window. The MainWindow is   #
-# main object of the editor containing the notebook, shelf, command bar    #
-# and other items.                                                         #
-#                                                                          #
-#--------------------------------------------------------------------------#
+FILE: ed_main.py
+AUTHOR: Cody Precord
+LANGUAGE: Python
+
+SUMMARY:
+This module provides the L{MainWindow} class for Editra. The MainWindow is
+main Ui component of the editor that contains all the other components.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 51588 2008-02-08 07:58:20Z CJP $"
-__revision__ = "$Revision: 51588 $"
+__svnid__ = "$Id: ed_main.py 52380 2008-03-08 10:30:35Z CJP $"
+__revision__ = "$Revision: 52380 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
-
 import os
 import sys
 import time
 import wx
 import wx.aui
+
+# Editra Libraries
 from ed_glob import *
 import util
 import profiler
@@ -41,6 +39,7 @@ import ed_pages
 import ed_menu
 import ed_print
 import ed_cmdbar
+import ed_statbar
 import ed_mdlg
 import syntax.syntax as syntax
 import generator
@@ -76,7 +75,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         viewmgr.PerspectiveManager.__init__(self, self._mgr, \
                                             CONFIG['CACHE_DIR'])
 
-        # Setup app icon and title 
+        # Setup app icon and title
         self.SetTitle()
         util.SetWindowIcon(self)
 
@@ -92,8 +91,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.filehistory = wx.FileHistory(_PGET('FHIST_LVL', 'int', 5))
 
         #---- Status bar on bottom of window ----#
-        self.CreateStatusBar(3, style=wx.ST_SIZEGRIP)
-        self.SetStatusWidths([-1, 90, 155])
+        self.SetStatusBar(ed_statbar.EdStatBar(self))
+
         #---- End Statusbar Setup ----#
 
         #---- Notebook that contains the editting buffers ----#
@@ -125,7 +124,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         ## Setup additional menu items
         self.filehistory.UseMenu(menbar.GetMenuByName("filehistory"))
-        menbar.GetMenuByName("settings").AppendMenu(ID_LEXER, _("Lexers"), 
+        menbar.GetMenuByName("settings").AppendMenu(ID_LEXER, _("Lexers"),
                                                     syntax.GenLexerMenu(),
                                               _("Manually Set a Lexer/Syntax"))
 
@@ -133,7 +132,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Note it must be done before setting the menu bar and after the
         # menus have been created.
         if wx.Platform == '__WXMAC__':
-            wx.GetApp().SetMacHelpMenuTitleName(_("Help"))
+            wx.GetApp().SetMacHelpMenuTitleName(_("&Help"))
 
         #---- Menu Bar ----#
         self.SetMenuBar(menbar)
@@ -157,9 +156,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_PRINT_SU, self.OnPrint),
 
                                        # Edit Menu
-                                       (ID_FIND, 
+                                       (ID_FIND,
                                         self.nb.FindService.OnShowFindDlg),
-                                       (ID_FIND_REPLACE, 
+                                       (ID_FIND_REPLACE,
                                         self.nb.FindService.OnShowFindDlg),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
@@ -178,17 +177,18 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
                                        # Help Menu
                                        (ID_ABOUT, OnAbout),
-                                       (ID_HOMEPAGE, OnHelp),
-                                       (ID_DOCUMENTATION, OnHelp),
-                                       (ID_CONTACT, OnHelp)])
+                                       (ID_HOMEPAGE, self.OnHelp),
+                                       (ID_DOCUMENTATION, self.OnHelp),
+                                       (ID_TRANSLATE, self.OnHelp),
+                                       (ID_CONTACT, self.OnHelp)])
 
-        self._handlers['menu'].extend([(l_id, self.DispatchToControl) 
+        self._handlers['menu'].extend([(l_id, self.DispatchToControl)
                                        for l_id in syntax.SyntaxIds()])
 
         # Extra menu handlers (need to work these into above system yet)
         self.Bind(wx.EVT_MENU, self.DispatchToControl)
         self.Bind(wx.EVT_MENU, self.OnGenerate)
-        self.Bind(wx.EVT_MENU_RANGE, self.OnFileHistory, 
+        self.Bind(wx.EVT_MENU_RANGE, self.OnFileHistory,
                   id=wx.ID_FILE1, id2=wx.ID_FILE9)
 
         # Update UI Handlers
@@ -199,7 +199,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_UNDO, self.OnUpdateClipboardUI),
                                      (ID_REDO, self.OnUpdateClipboardUI),
                                      # Format Menu
+                                     (ID_INDENT, self.OnUpdateFormatUI),
                                      (ID_USE_SOFTTABS, self.OnUpdateFormatUI),
+                                     (ID_TO_UPPER, self.OnUpdateFormatUI),
+                                     (ID_TO_LOWER, self.OnUpdateFormatUI),
                                      (ID_WORD_WRAP, self.OnUpdateFormatUI),
                                      (ID_EOL_MAC, self.OnUpdateFormatUI),
                                      (ID_EOL_WIN, self.OnUpdateFormatUI),
@@ -223,7 +226,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                     ])
 
         # Lexer Menu
-        self._handlers['ui'].extend([(l_id, self.OnUpdateLexerUI) 
+        self._handlers['ui'].extend([(l_id, self.OnUpdateLexerUI)
                                      for l_id in syntax.SyntaxIds()])
 
         # Perspectives
@@ -317,7 +320,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         for win in wx.GetApp().GetMainWindows():
             if hasattr(win, 'filehistory'):
                 win.filehistory.AddFileToHistory(fname)
-        
+
     def DoOpen(self, evt, fname=u''):
         """ Do the work of opening a file and placing it
         in a new notebook page.
@@ -348,7 +351,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                         wx.GetApp().OpenNewWindow(path)
                     else:
                         self.nb.OpenPage(util.GetPathName(path),
-                                         util.GetFileName(path))   
+                                         util.GetFileName(path))
                         self.nb.GoCurrentPage()
 
             dlg.Destroy()
@@ -473,13 +476,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         e_id = evt.GetId()
         ctrls = list()
         if e_id == ID_SAVE:
-            ctrls = [(self.nb.GetPageText(self.nb.GetSelection()), 
+            ctrls = [(self.nb.GetPageText(self.nb.GetSelection()),
                      self.nb.GetCurrentCtrl())]
         elif e_id == ID_SAVEALL:
             for page in xrange(self.nb.GetPageCount()):
-                if issubclass(self.nb.GetPage(page).__class__, 
+                if issubclass(self.nb.GetPage(page).__class__,
                                            wx.stc.StyledTextCtrl):
-                    ctrls.append((self.nb.GetPageText(page), 
+                    ctrls.append((self.nb.GetPageText(page),
                                   self.nb.GetPage(page)))
         else:
             evt.Skip()
@@ -493,10 +496,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 if result:
                     self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
                 else:
-                    err = ctrl[1].GetDocPointer().GetLastError()
+                    err = ctrl[1].GetDocument().GetLastError()
                     self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
                     ed_mdlg.SaveErrorDlg(self, fname, err)
-                    ctrl[1].GetDocPointer().ClearLastError()
+                    ctrl[1].GetDocument().ResetAll()
             else:
                 ret_val = self.OnSaveAs(ID_SAVEAS, ctrl[0], ctrl[1])
                 if ret_val:
@@ -508,9 +511,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wxMenuEvent
 
         """
-        dlg = wx.FileDialog(self, _("Choose a Save Location"), '', 
-                            title.lstrip("*"), 
-                            ''.join(syntax.GenFileFilters()), 
+        dlg = wx.FileDialog(self, _("Choose a Save Location"), '',
+                            title.lstrip("*"),
+                            ''.join(syntax.GenFileFilters()),
                             wx.SAVE | wx.OVERWRITE_PROMPT)
 
         if dlg.ShowModal() == wx.ID_OK:
@@ -525,9 +528,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             result = ctrl.SaveFile(path)
             fname = util.GetFileName(ctrl.GetFileName())
             if not result:
-                err = ctrl.GetDocPointer().GetLastError()
+                err = ctrl.GetDocument().GetLastError()
                 ed_mdlg.SaveErrorDlg(self, fname, err)
-                ctrl.GetDocPointer().ClearLastError()
+                ctrl.GetDocument().ResetAll()
                 self.PushStatusText(_("ERROR: Failed to save %s") % fname, SB_INFO)
             else:
                 self.PushStatusText(_("Saved File As: %s") % fname, SB_INFO)
@@ -548,7 +551,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if evt.GetId() == ID_SAVE_PROFILE:
             dlg = wx.FileDialog(self, _("Where to Save Profile?"), \
                                CONFIG['PROFILE_DIR'], "default.ppb", \
-                               _("Profile") + " (*.ppb)|*.ppb", 
+                               _("Profile") + " (*.ppb)|*.ppb",
                                 wx.SAVE | wx.OVERWRITE_PROMPT)
 
             if dlg.ShowModal() == wx.ID_OK:
@@ -567,12 +570,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         if evt.GetId() == ID_LOAD_PROFILE:
-            dlg = wx.FileDialog(self, _("Load a Custom Profile"), 
-                                CONFIG['PROFILE_DIR'], "default.ppb", 
+            dlg = wx.FileDialog(self, _("Load a Custom Profile"),
+                                CONFIG['PROFILE_DIR'], "default.ppb",
                                 _("Profile") + " (*.ppb)|*.ppb", wx.OPEN)
 
             result = dlg.ShowModal()
-            if result == wx.ID_OK: 
+            if result == wx.ID_OK:
                 profiler.Profile().Load(dlg.GetPath())
                 self.PushStatusText(_("Loaded Profile: %s") % \
                                     dlg.GetFilename(), SB_INFO)
@@ -589,8 +592,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @param evt: event that called this handler
 
         """
-        if self.GetStatusBar():
-            self.PushStatusText(evt.GetMessage(), evt.GetSection())
+        statbar = self.GetStatusBar()
+        if statbar:
+            # The frames Set/PushStatusText methods don't seem to call the
+            # method of the statusbar class instance when setting the text so
+            # get and set the text in the status bar directly so that our
+            # statusbar's overridden settext method gets called
+            statbar.SetStatusText(evt.GetMessage(), evt.GetSection())
+#            self.SetStatusText(evt.GetMessage(), evt.GetSection())
 
     def OnPrint(self, evt):
         """Handles sending the current document to the printer,
@@ -678,7 +687,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         self.LOG("[ed_main][evt] OnClose: Closing editor at pos=%s size=%s" % \
                  (_PGET('WPOS', 'str'), _PGET('WSIZE', 'str')))
-        
+
         # Update profile
         profiler.AddFileHistoryToProfile(self.filehistory)
         profiler.Profile().Write(_PGET('MYPROFILE'))
@@ -706,9 +715,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     #---- View Menu Functions ----#
     def OnViewTb(self, evt):
         """Toggles visibility of toolbar
-        @note: On OSX there is a frame button for hidding the toolbar
-               that is handled internally by the osx toolbar and not this
-               handler.
         @param evt: Event fired that called this handler
         @type evt: wxMenuEvent
 
@@ -813,7 +819,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if doc:
             self.nb.NewPage()
             ctrl = self.nb.GetCurrentCtrl()
-            ctrl.SetText(doc[1]) 
+            ctrl.SetText(doc[1])
             ctrl.FindLexer(doc[0])
         else:
             evt.Skip()
@@ -833,9 +839,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         ctrl = self.nb.GetCurrentCtrl()
         active_only = [ ID_ZOOM_IN, ID_ZOOM_OUT, ID_ZOOM_NORMAL,
-                        ID_JOIN_LINES, ID_CUT_LINE, ID_COPY_LINE, ID_INDENT, 
+                        ID_JOIN_LINES, ID_CUT_LINE, ID_COPY_LINE, ID_INDENT,
                         ID_UNINDENT, ID_TRANSPOSE, ID_COMMENT, ID_UNCOMMENT,
-                        ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY, 
+                        ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE ]
 
         has_focus = self.FindFocus()
@@ -860,11 +866,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         menu_ids = syntax.SyntaxIds()
         menu_ids.extend([ID_SHOW_EOL, ID_SHOW_WS, ID_INDENT_GUIDES, ID_SYNTAX,
                          ID_WORD_WRAP, ID_BRACKETHL, ID_EOL_MAC, ID_EOL_UNIX,
-                         ID_EOL_WIN, ID_NEXT_MARK, ID_PRE_MARK, ID_ADD_BM, 
-                         ID_DEL_BM, ID_DEL_ALL_BM, ID_FOLDING, ID_AUTOCOMP, 
-                         ID_SHOW_LN,  ID_AUTOINDENT, ID_TAB_TO_SPACE, 
-                         ID_SPACE_TO_TAB, ID_TRIM_WS, ID_SHOW_EDGE, 
-                         ID_MACRO_START, ID_MACRO_STOP, ID_MACRO_PLAY, 
+                         ID_EOL_WIN, ID_NEXT_MARK, ID_PRE_MARK, ID_ADD_BM,
+                         ID_DEL_BM, ID_DEL_ALL_BM, ID_FOLDING, ID_AUTOCOMP,
+                         ID_SHOW_LN,  ID_AUTOINDENT, ID_TAB_TO_SPACE,
+                         ID_SPACE_TO_TAB, ID_TRIM_WS, ID_SHOW_EDGE,
+                         ID_MACRO_START, ID_MACRO_STOP, ID_MACRO_PLAY,
                          ID_TO_LOWER, ID_TO_UPPER, ID_KWHELPER, ID_USE_SOFTTABS
                          ])
         menu_ids.extend(active_only)
@@ -912,13 +918,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
         evt.SetUpdateInterval(300)
         ctrl = self.nb.GetCurrentCtrl()
-        eol = ctrl.GetEOLModeId()
         if e_id == ID_USE_SOFTTABS:
             evt.Check(not bool(ctrl.GetUseTabs()))
         elif e_id == ID_WORD_WRAP:
             evt.Check(bool(ctrl.GetWrapMode()))
         elif e_id in [ID_EOL_MAC, ID_EOL_WIN, ID_EOL_UNIX]:
-            evt.Check(eol == e_id)
+            evt.Check(ctrl.GetEOLModeId() == e_id)
+        elif e_id in [ID_INDENT, ID_TO_UPPER, ID_TO_LOWER]:
+            evt.Enable(ctrl.GetSelectionStart() != ctrl.GetSelectionEnd())
         else:
             evt.Skip()
 
@@ -1015,6 +1022,37 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Skip()
         self.sizer.Layout()
 
+    def OnHelp(self, evt):
+        """Handles help related menu events
+        @param evt: Event fired that called this handler
+        @type evt: wxMenuEvent
+
+        """
+        import webbrowser
+
+        e_id = evt.GetId()
+        if e_id == ID_HOMEPAGE:
+            page = HOME_PAGE
+        elif e_id == ID_DOCUMENTATION:
+            page = HOME_PAGE + "/?page=doc"
+        elif e_id == ID_TRANSLATE:
+            page = I18N_PAGE
+        elif e_id == ID_CONTACT:
+            webbrowser.open("mailto:%s" % CONTACT_MAIL)
+            return
+        else:
+            evt.Skip()
+            return
+
+        # It seems under some cases when running under windows the call to
+        # subprocess in webbrowser will fail and raise an exception here. So
+        # simply trap and ingnore it.
+        try:
+            self.PushStatusText(_("Opening %s") % page, SB_INFO)
+            webbrowser.open(page, 1)
+        except:
+            self.PushStatusText(_("Error: Unable to open %s") % page, SB_INFO)
+
     def ShowCommandCtrl(self):
         """Open the Commandbar in command mode.
         @todo: check if this is necessary
@@ -1034,11 +1072,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if name == u"":
             name = self.nb.GetPageText(self.nb.GetSelection())
 
-        dlg = wx.MessageDialog(self, 
+        dlg = wx.MessageDialog(self,
                                 _("The file: \"%s\" has been modified since "
                                   "the last save point.\n\nWould you like to "
-                                  "save the changes?") % name, 
-                               _("Save Changes?"), 
+                                  "save the changes?") % name,
+                               _("Save Changes?"),
                                wx.YES_NO | wx.YES_DEFAULT | wx.CANCEL | \
                                wx.ICON_INFORMATION)
         result = dlg.ShowModal()
@@ -1060,7 +1098,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             name = " - " + name
         wx.Frame.SetTitle(self, title + name)
 
-
 #-----------------------------------------------------------------------------#
 # Event handlers that don't need to be part of the class
 
@@ -1073,17 +1110,17 @@ def OnAbout(evt):
     if evt.GetId() == ID_ABOUT:
         info = wx.AboutDialogInfo()
         year = time.localtime()
-        desc = ["Editra is a programmers text editor.",
-                "Written in 100%% Python.",
-                "Homepage: " + HOME_PAGE + "\n",
-                "Platform Info: (%s,%s)", 
-                "License: wxWindows (see COPYING.txt for full license)"]
+        desc = [_("Editra is a programmers text editor."),
+                _("Written in 100%% Python."),
+                _("Homepage") + ": " + HOME_PAGE + "\n",
+                _("Platform Info") + ": (%s,%s)",
+                _("License: wxWindows (see COPYING.txt for full license)")]
         desc = "\n".join(desc)
         py_version = sys.platform + ", python " + sys.version.split()[0]
         platform = list(wx.PlatformInfo[1:])
         platform[0] += (" " + wx.VERSION_STRING)
         wx_info = ", ".join(platform)
-        info.SetCopyright("Copyright(C) 2005-%d Cody Precord" % year[0])
+        info.SetCopyright(_("Copyright") + "(C) 2005-%d Cody Precord" % year[0])
         info.SetName(PROG_NAME.title())
         info.SetDescription(desc % (py_version, wx_info))
         info.SetVersion(VERSION)
@@ -1091,26 +1128,9 @@ def OnAbout(evt):
     else:
         evt.Skip()
 
-def OnHelp(evt):
-    """Handles help related menu events
-    @param evt: Event fired that called this handler
-    @type evt: wxMenuEvent
-
-    """
-    import webbrowser
-    e_id = evt.GetId()
-    if e_id == ID_HOMEPAGE:
-        webbrowser.open(HOME_PAGE, 1)
-    elif e_id == ID_DOCUMENTATION:
-        webbrowser.open(HOME_PAGE + "/?page=doc", 1)
-    elif e_id == ID_CONTACT:
-        webbrowser.open("mailto:%s" % CONTACT_MAIL)
-    else:
-        evt.Skip()
-
 def OnPreferences(evt):
     """Open the Preference Panel
-    @note: The dialogs module is not imported until this is 
+    @note: The dialogs module is not imported until this is
            first called so the first open may lag a little.
     @param evt: Event fired that called this handler
     @type evt: wxMenuEvent
