@@ -19,8 +19,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 49415 2007-10-25 05:06:57Z CJP $"
-__revision__ = "$Revision: 49415 $"
+__svnid__ = "$Id: ed_search.py 51096 2008-01-08 08:03:46Z CJP $"
+__revision__ = "$Revision: 51096 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -158,13 +158,15 @@ class TextFinder(object):
             pool.SetSearchFlags(flag_map[s_flags - wx.FR_DOWN] | \
                                 wx.stc.STC_FIND_REGEXP)
             replaced = 0
+            pool.BeginUndoAction()
             while pool.SearchInTarget(query) > 0:
                 pool.SetSelection(pool.GetTargetStart(), pool.GetTargetEnd())
                 pool.ReplaceSelection(replacestring)
-                pool.SetTargetStart(pool.GetTargetEnd() - (len(query) - \
-                                    len(replacestring)))
-                pool.SetTargetEnd(pool.GetLength())
                 replaced += 1
+                pool.SetTargetStart(pool.GetTargetStart() + len(replacestring))
+                pool.SetTargetEnd(pool.GetLength())
+            pool.EndUndoAction()
+
             pool.ScrollToLine(self._posinfo['scroll'])
             pool.SetCurrentPos(self._posinfo['start']) # Move cursor to start
             pool.SetSelection(self._posinfo['start'], self._posinfo['start'])
@@ -197,6 +199,16 @@ class TextFinder(object):
         """
         return self._data.GetFlags()
 
+    def GetStart(self):
+        """Get the value of the start position that was last set by a call
+        to L{SetStart}.
+        @return: integer position value
+        @note: usually the returned value is the cursors position from the
+               begining of the last search operation.
+
+        """
+        return self._poinfo['start']
+
     def OnFindClose(self, evt):
         """Destroy Find Dialog After Cancel is clicked in it
         @param evt: event that called this handler
@@ -228,8 +240,7 @@ class TextFinder(object):
         else:
             evt.Skip()
             return
-        if wx.Platform == '__WXMAC__' and Profile_Get('METAL', 'bool', False):
-            self._find_dlg.SetExtraStyle(wx.DIALOG_EX_METAL)
+
         self._find_dlg.CenterOnParent()
         try:
             self._find_dlg.Show()
@@ -282,7 +293,7 @@ class EdSearchCtrl(wx.SearchCtrl):
     """
     def __init__(self, parent, id_, value="", menulen=0, \
                  pos=wx.DefaultPosition, size=wx.DefaultSize, \
-                 style=wx.TE_RICH2):
+                 style=wx.TE_RICH2|wx.TE_PROCESS_ENTER):
         """Initializes the Search Control
         @param menulen: max length of history menu
 
@@ -306,13 +317,13 @@ class EdSearchCtrl(wx.SearchCtrl):
         self.SetMenu(self.rmenu)
 
         # Bind Events
-        if wx.Platform == '__WXMSW__':
+        if wx.Platform in ['__WXMSW__', '__WXGTK__']:
             for child in self.GetChildren():
                 if isinstance(child, wx.TextCtrl):
                     child.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
                     break
-
-        self.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
+        else:
+            self.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
         self.Bind(wx.EVT_SEARCHCTRL_CANCEL_BTN, self.OnCancel)
         self.Bind(wx.EVT_MENU, self.OnHistMenu)
 
@@ -324,6 +335,39 @@ class EdSearchCtrl(wx.SearchCtrl):
         """
         self._flags ^= flag
 
+    def DoSearch(self, next=True):
+        """Do the search and move the selection
+        @keyword next: search next or previous
+
+        """
+        s_cmd = wx.wxEVT_COMMAND_FIND
+        if next:
+            self.SetSearchFlag(wx.FR_DOWN)
+        else:
+            if wx.FR_DOWN & self._flags:
+                self.ClearSearchFlag(wx.FR_DOWN)
+
+        if self.GetValue() == self._last:
+            s_cmd = wx.wxEVT_COMMAND_FIND_NEXT
+        self.InsertHistoryItem(self.GetValue())
+
+        self._last = self.GetValue()
+        self.FindService.SetQueryString(self.GetValue())
+        self.FindService.SetSearchFlags(self._flags)
+        self.FindService.OnFind(wx.FindDialogEvent(s_cmd))
+
+        # Give feedback on whether text was found or not
+        if self.FindService.GetLastFound() < 0 and len(self.GetValue()) > 0:
+            self.SetForegroundColour(wx.RED)
+            wx.Bell()
+        else:
+            # ?wxBUG? cant set text back to black after changing color
+            # But setting it to this almost black color works. Most likely its
+            # due to bit masking but I havent looked at the source so I am not
+            # sure
+            self.SetForegroundColour(wx.ColorRGB(0 | 1 | 0))
+        self.Refresh()
+
     def GetSearchData(self):
         """Gets the find data from the controls FindService
         @return: search data
@@ -352,7 +396,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             return
 
         # Make sure menu only has unique items
-        m_items = self.rmenu.GetMenuItems()
+        m_items = list(self.rmenu.GetMenuItems())
         for menu_i in m_items:
             if value == menu_i.GetLabel():
                 self.rmenu.RemoveItem(menu_i)
@@ -372,7 +416,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             try:
                 self.rmenu.RemoveItem(m_items[-1])
             except IndexError, msg:
-                wx.GetApp().GetLog()("[searchbar] menu error: %s" % str(msg))
+                wx.GetApp().GetLog()("[ed_search][err] menu error: %s" % str(msg))
 
     def IsMatchCase(self):
         """Returns True if the search control is set to search
@@ -444,7 +488,7 @@ class EdSearchCtrl(wx.SearchCtrl):
 
         e_key = evt.GetKeyCode()
         if e_key == wx.WXK_ESCAPE:
-            # HACK change to more safely determine the context
+            # TODO change to more safely determine the context
             # Currently control is only used in command bar
             self.GetParent().Hide()
             return
@@ -464,35 +508,13 @@ class EdSearchCtrl(wx.SearchCtrl):
             return
 
         s_cmd = wx.wxEVT_COMMAND_FIND
-        if e_key == wx.WXK_RETURN:
+        if e_key == wx.WXK_RETURN or e_key == wx.WXK_F3:
             if evt.ShiftDown():
-                if wx.FR_DOWN & self._flags:
-                    self.ClearSearchFlag(wx.FR_DOWN)
+                self.DoSearch(next=False)
             else:
-                self.SetSearchFlag(wx.FR_DOWN)
-
-            if self.GetValue() == self._last:
-                s_cmd = wx.wxEVT_COMMAND_FIND_NEXT
-            self.InsertHistoryItem(self.GetValue())
+                self.DoSearch(next=True)
         else:
-            self.SetSearchFlag(wx.FR_DOWN)
-
-        self._last = self.GetValue()
-        self.FindService.SetQueryString(self.GetValue())
-        self.FindService.SetSearchFlags(self._flags)
-        self.FindService.OnFind(wx.FindDialogEvent(s_cmd))
-
-        # Give feedback on whether text was found or not
-        if self.FindService.GetLastFound() < 0 and len(self.GetValue()) > 0:
-            self.SetForegroundColour(wx.RED)
-            wx.Bell()
-        else:
-            # ?wxBUG? cant set text back to black after changing color
-            # But setting it to this almost black color works. Most likely its
-            # due to bit masking but I havent looked at the source so I am not
-            # sure
-            self.SetForegroundColour(wx.ColorRGB(0 | 1 | 0))
-        self.Refresh()
+            self.DoSearch(next=True)
 
     def OnCancel(self, evt):
         """Cancels the Search Query
