@@ -7,25 +7,23 @@
 ###############################################################################
 
 """
-#-----------------------------------------------------------------------------#
-# FILE: ed_stc.py                                                             #
-# LANGUAGE: Python                                                            #
-# AUTHOR: Cody Precord                                                        #
-#                                                                             #
-# SUMMARY:                                                                    #
-#  This is the main component of the editor that manages all the information  #
-# of the on disk file that it represents in memory. It works with the         #
-# L{ed_style.StyleManager} and L{syntax.syntax.SyntaxManager} to provide an   #
-# editing pane that auto detects and configures itself for type of file that  #
-# is in buffer to do highlighting and other language specific options such as #
-# commenting code.                                                            #
-#                                                                             #
-#-----------------------------------------------------------------------------#
+FILE: ed_stc.py
+LANGUAGE: Python
+AUTHOR: Cody Precord
+
+SUMMARY:
+ This is the main component of the editor that manages all the information
+of the on disk file that it represents in memory. It works with the
+L{ed_style.StyleManager} and L{syntax.syntax.SyntaxManager} to provide an
+editing pane that auto detects and configures itself for type of file that
+is in buffer to do highlighting and other language specific options such as
+commenting code.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 51587 2008-02-08 07:55:51Z CJP $"
-__revision__ = "$Revision: 51587 $"
+__svnid__ = "$Id: ed_stc.py 52480 2008-03-14 08:01:27Z CJP $"
+__revision__ = "$Revision: 52480 $"
 
 #-------------------------------------------------------------------------#
 # Dependencies
@@ -42,6 +40,7 @@ import util
 import ed_style
 import ed_msg
 import ed_txt
+from ed_keyh import KeyHandler, ViKeyHandler
 
 #-------------------------------------------------------------------------#
 # Globals
@@ -52,16 +51,9 @@ MARK_MARGIN = 0
 NUM_MARGIN  = 1
 FOLD_MARGIN = 2
 
-# Vi command patterns
-VI_DCMD_RIGHT = '[bBcdeEGhHlLMwWy|{}$<>]'
-VI_DOUBLE_P1 = re.compile('[cdy<>][0-9]*' + VI_DCMD_RIGHT)
-VI_DOUBLE_P2 = re.compile('[0-9]*[cdy<>]' + VI_DCMD_RIGHT)
-VI_SINGLE_REPEAT = re.compile('[0-9]*[bBCDeEGhjJkloOpPsuwWxX{}~|+-]')
-NUM_PAT = re.compile('[0-9]*')
+SPACECHARS = " \t\r\n"
 NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
            "0123456789_./\?[]{}<>!@#$%^&*():=-+\"';,"
-SPACECHARS = " \t\r\n"
-
 #-------------------------------------------------------------------------#
 class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     """Defines a styled text control for editing text
@@ -99,8 +91,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
-        self._vi = dict(vimode=False, normal=False,
-                        last=u'', cmdcache=u'')
+        self.key_handler = KeyHandler(self)
 
         # File Attributes
         self.file = ed_txt.EdFile()
@@ -124,7 +115,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                           comment=list(),
                           lang_id=0)        # Language ID from syntax module
 
-        # Set Up Margins 
+        # Set Up Margins
         ## Outer Left Margin Bookmarks
         self.SetMarginType(MARK_MARGIN, wx.stc.STC_MARGIN_SYMBOL)
         self.SetMarginMask(MARK_MARGIN, self.ED_STC_MASK_MARKERS)
@@ -153,7 +144,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
-        self.Bind(wx.EVT_LEFT_UP, self.OnKeyUp)
+        self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
 
        #---- End Init ----#
 
@@ -520,19 +511,19 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         back = self.GetDefaultForeColour()
         fore = self.GetDefaultBackColour()
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPEN, 
+        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPEN,
                           wx.stc.STC_MARK_BOXMINUS, fore, back)
         self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDER,
                           wx.stc.STC_MARK_BOXPLUS,  fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERSUB,     
+        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERSUB,
                           wx.stc.STC_MARK_VLINE, fore, back)
         self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERTAIL,
                           wx.stc.STC_MARK_LCORNER, fore, back)
         self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEREND,
                           wx.stc.STC_MARK_BOXPLUSCONNECTED, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPENMID, 
+        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPENMID,
                           wx.stc.STC_MARK_BOXMINUSCONNECTED, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERMIDTAIL, 
+        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERMIDTAIL,
                           wx.stc.STC_MARK_TCORNER, fore, back)
         self.MarkerDefine(0, wx.stc.STC_MARK_SHORTARROW, fore, back)
         self.SetFoldMarginHiColour(True, fore)
@@ -564,9 +555,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self.file.GetPath()
 
-    def GetDocPointer(self):
-        """Return a reference to the document object represented
-        in this buffer.
+    def GetDocument(self):
+        """Return a reference to the document object represented in this buffer.
         @return: EdFile
         @see: L{ed_txt.EdFile}
 
@@ -608,11 +598,11 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         k_code = evt.GetKeyCode()
         if not evt.ShiftDown() and \
-           self._vi['vimode'] and \
+           self.key_handler.GetHandlerName() == u'VI' and \
            k_code == wx.WXK_ESCAPE:
             # If Vi emulation is active go into Normal mode and
             # pass the key event to OnChar
-            self.SetViNormalMode(True)
+            self.key_handler.SetMode(ViKeyHandler.NORMAL)
             evt.Skip()
             return
         elif k_code == wx.WXK_RETURN:
@@ -642,9 +632,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         key_code = evt.GetKeyCode()
-        if self._vi['vimode'] and self._vi['normal']:
-            self._vi['cmdcache'] = self._vi['cmdcache'] + unichr(key_code)
-            self.ViCmdDispatch()
+        if self.key_handler.ProcessKey(key_code):
+            # The key handler handled this keypress, we don't need to insert
+            # the character into the buffer.
+            pass
         elif not self._config['autocomp']:
             evt.Skip()
             return
@@ -668,19 +659,21 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def OnKeyUp(self, evt):
         """Update status bar of window
-        @param evt: wxEVT_KEY_UP / wxEVT_LEFT_UP
+        @param evt: wxEVT_KEY_UP
 
         """
         evt.Skip()
+        self.PostPositionEvent()
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_KEYUP,
+                           (evt.GetPositionTuple(), evt.GetKeyCode()))
+
+    def PostPositionEvent(self):
+        """Post an event to update the status of the line/column"""
         msg = _("Line: %d  Column: %d") % self.GetPos()
-        nevt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(), 
+        nevt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
                                     msg, ed_glob.SB_ROWCOL)
         wx.PostEvent(self.GetTopLevelParent(), nevt)
 
-        if isinstance(evt, wx.KeyEvent):
-            ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_KEYUP,
-                               (evt.GetPositionTuple(), evt.GetKeyCode()))
-
     def OnRecordMacro(self, evt):
         """Records macro events
         @param evt: event that called this handler
@@ -786,9 +779,25 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         elif len(self._code['keywords']) > 1:
             pos = self.GetCurrentPos()
             pos2 = self.WordStartPosition(pos, True)
+            print pos, pos2
             self.AutoCompShow(pos - pos2, self._code['keywords'])
         return
 
+    def OnLeftUp(self, evt):
+        """Set primary selection and inform mainwindow that cursor position 
+        has changed.
+        @param evt: wx.MouseEvent()
+
+        """
+        evt.Skip()
+        # FIXME: there is problems with using the primary selection. Setting
+        #        the primary selection causes anything else on the clipboard
+        #        to get killed.
+#        stxt = self.GetSelectedText()
+#        if len(stxt):
+#            util.SetClipboardText(stxt, primary=True)
+        self.PostPositionEvent()
+
     def OnModified(self, evt):
         """Handles updates that need to take place after
         the control has been modified.
@@ -813,7 +822,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             char_before = self.GetCharAt(caret_pos - 1)
 
         # check before
-        if char_before and chr(char_before) in "[]{}()<>": 
+        if char_before and chr(char_before) in "[]{}()<>":
             brace_at_caret = caret_pos - 1
 
         # check after
@@ -983,25 +992,25 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_PASTE : self.Paste, ed_glob.ID_UNDO : self.Undo,
                   ed_glob.ID_REDO  : self.Redo, ed_glob.ID_INDENT : self.Tab,
                   ed_glob.ID_KWHELPER: self.ShowKeywordHelp,
-                  ed_glob.ID_CUT_LINE : self.LineCut, 
+                  ed_glob.ID_CUT_LINE : self.LineCut,
                   ed_glob.ID_COPY_LINE : self.LineCopy,
                   ed_glob.ID_DUP_LINE : self.LineDuplicate,
                   ed_glob.ID_BRACKETHL : self.ToggleBracketHL,
                   ed_glob.ID_SYNTAX : self.SyntaxOnOff,
                   ed_glob.ID_UNINDENT : self.BackTab,
-                  ed_glob.ID_TRANSPOSE : self.LineTranspose, 
+                  ed_glob.ID_TRANSPOSE : self.LineTranspose,
                   ed_glob.ID_SELECTALL: self.SelectAll,
-                  ed_glob.ID_FOLDING : self.FoldingOnOff, 
+                  ed_glob.ID_FOLDING : self.FoldingOnOff,
                   ed_glob.ID_SHOW_LN : self.ToggleLineNumbers,
-                  ed_glob.ID_COMMENT : self.Comment, 
+                  ed_glob.ID_COMMENT : self.Comment,
                   ed_glob.ID_AUTOINDENT : self.ToggleAutoIndent,
-                  ed_glob.ID_LINE_AFTER : self.AddLine, 
+                  ed_glob.ID_LINE_AFTER : self.AddLine,
                   ed_glob.ID_TRIM_WS : self.TrimWhitespace,
-                  ed_glob.ID_MACRO_START : self.StartRecord, 
+                  ed_glob.ID_MACRO_START : self.StartRecord,
                   ed_glob.ID_MACRO_STOP : self.StopRecord,
                   ed_glob.ID_MACRO_PLAY : self.PlayMacro
         }
-        
+
         e_idmap = { ed_glob.ID_ZOOM_OUT : self.DoZoom,
                     ed_glob.ID_ZOOM_IN  : self.DoZoom,
                     ed_glob.ID_ZOOM_NORMAL : self.DoZoom,
@@ -1071,7 +1080,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         mixed = diff = False
-        eol_map = {"\n" : wx.stc.STC_EOL_LF, 
+        eol_map = {"\n" : wx.stc.STC_EOL_LF,
                    "\r\n" : wx.stc.STC_EOL_CRLF,
                    "\r" : wx.stc.STC_EOL_CR}
         eol = chr(self.GetCharAt(self.GetLineEndPosition(0)))
@@ -1241,6 +1250,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetTargetEnd(self.GetLineEndPosition(eline))
         self.ReplaceTarget(u' '.join(lines))
 
+    def LineTranspose(self):
+        """Switch the current line with the previous one
+        @note: overrides base stc method to do transpose in single undo action
+
+        """
+        self.BeginUndoAction()
+        wx.stc.StyledTextCtrl.LineTranspose(self)
+        self.EndUndoAction()
+
     def SetAutoComplete(self, value):
         """Turns Autocompletion on and off
         @param value: use autocomp or not
@@ -1252,7 +1270,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             if value:
                 self._code['compsvc'].LoadCompProvider(self.GetLexer())
 
-    def SetDocPointer(self, doc):
+    def SetDocument(self, doc):
         """Change the document object used.
         @param doc: an L{ed_txt.EdFile} instance
 
@@ -1294,29 +1312,11 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type use_vi: boolean
 
         """
-        self._vi['vimode'] = use_vi
-        self.SetViNormalMode(False)  # Use input mode by default
-        self._vi['cmdcache'] = u'' # clear all cmds when switching modes
-
-    def SetViNormalMode(self, normal):
-        """Change the cursor appearance when toggling
-        in and out of vi normal mode.
-        @param normal: Normal mode on/off
-        @type normal: boolean
-
-        """
-        self._vi['normal'] = normal
-        self._vi['cmdcache'] = u''
-        if normal:
-            self.SetCaretWidth(10)
-            msg = 'NORMAL'
+        self.key_handler.ClearMode()
+        if use_vi:
+            self.key_handler = ViKeyHandler(self)
         else:
-            self.SetCaretWidth(1)
-            msg = 'INSERT'
-
-        evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(), 
-                                   msg, ed_glob.SB_BUFF)
-        wx.PostEvent(self.GetTopLevelParent(), evt)
+            self.key_handler = KeyHandler(self)
 
     def SetViewEdgeGuide(self, switch=None):
         """Toggles the visibility of the edge guide
@@ -1369,7 +1369,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 if not eol.isspace():
                     eol = u''
             else:
-                eol = u''            
+                eol = u''
             if line == cline:
                 npos = cpos - (abs(len(self.GetTextRange(0, \
                                        self.GetLineEndPosition(cline-1))) - \
@@ -1382,309 +1382,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetText(txt)
         self.GotoPos(cpos)
 
-    def ViCmdDispatch(self):
-        """Processes vi commands
-        @todo: complete rewrite, this was initially intended as a quick hack
-               put together for testing but now has implemented everything.
-
-        """
-        if not len(self._vi['cmdcache']):
-            return
-
-        if self._vi['cmdcache'] != u'.':
-            cmd = self._vi['cmdcache']
-        else:
-            cmd = self._vi['last']
-        cpos = self.GetCurrentPos()
-        cline = self.LineFromPosition(cpos)
-        mw = self.GetTopLevelParent()
-        if u':' in cmd:
-            self._vi['cmdcache'] = u''
-            mw.ShowCommandCtrl()
-
-        # Single key commands
-        if len(cmd) == 1 and (cmd in 'AHILmM0^$nia/?:'):
-            if  cmd in u'A$': # Insert at EOL
-                self.GotoPos(self.GetLineEndPosition(cline))
-            elif cmd == u'H': # Go first visible line # todo allow num
-                self.GotoIndentPos(self.GetFirstVisibleLine())
-            elif cmd in u'I^': # Insert at line start / Jump line start
-                self.GotoIndentPos(cline)
-            elif cmd == u'0': # Jump to line start column 0
-                self.GotoPos(self.PositionFromLine(cline))
-            elif cmd == u'L': # Goto start of last visible line # todo allow num
-                self.GotoIndentPos(self.GetLastVisibleLine())
-            elif cmd == u'M': # Goto middle line of display
-                self.GotoIndentPos(self.GetMiddleVisibleLine())
-            elif cmd == u'm': # Mark line
-                if self.MarkerGet(cline):
-                    self.Bookmark(ed_glob.ID_DEL_BM)
-                else:
-                    self.Bookmark(ed_glob.ID_ADD_BM)
-            elif cmd == u'a': # insert mode after current pos
-                self.GotoPos(cpos + 1)
-            elif cmd in u'/?':
-                if mw is not None:
-                    evt = wx.MenuEvent(wx.wxEVT_COMMAND_MENU_SELECTED,
-                                       ed_glob.ID_QUICK_FIND)
-                    wx.PostEvent(mw, evt)
-
-            if cmd in u'aAiI':
-                self.SetViNormalMode(False)
-
-            self._vi['last'] = cmd
-            self._vi['cmdcache'] = u''
-        # Repeatable 1 key commands
-        elif re.match(VI_SINGLE_REPEAT, cmd):
-            rcmd = cmd[-1]
-            repeat = cmd[0:-1]
-            if repeat == u'':
-                repeat = 1
-            else:
-                repeat = int(repeat)
-
-            args = list()
-            kargs = dict()
-            cmd_map = { u'b' : self.WordPartLeft,
-                       u'B' : self.WordLeft,
-                       u'e' : self.WordPartRightEnd,
-                       u'E' : self.WordRightEnd,
-                       u'h' : self.CharLeft,
-                       u'j' : self.LineDown,
-                       u'k' : self.LineUp,
-                       u'l' : self.CharRight,
-                       u'o' : self.AddLine,
-                       u'O' : self.AddLine,
-                       u'p' : self.Paste,
-                       u'P' : self.Paste,
-                       u's' : self.Cut,
-                       u'u' : self.Undo,
-                       u'w' : self.WordPartRight,
-                       u'W' : self.WordRight,
-                       u'x' : self.Cut,
-                       u'X' : self.Cut,
-                       u'{' : self.ParaUp,
-                       u'}' : self.ParaDown,
-                       u'~' : self.InvertCase }
-
-            if rcmd in u'pP':
-                success = False
-                newline = False
-                if wx.TheClipboard.Open():
-                    td = wx.TextDataObject()
-                    success = wx.TheClipboard.GetData(td)
-                    wx.TheClipboard.Close()
-                if success:
-                    text = td.GetText()
-                    if text[-1] == '\n':
-                        if cline == self.GetLineCount() - 1 and rcmd == u'p':
-                            self.NewLine()
-                        else:
-                            if rcmd == u'P':
-                                self.GotoLine(cline)
-                            else:
-                                self.GotoLine(cline + 1)
-                        newline = True
-                    elif rcmd == u'p' and \
-                         self.LineFromPosition(cpos + 1) == cline:
-                        self.CharRight()
-            elif rcmd in u'sxX~':
-                if rcmd in u'sx~':
-                    tmp = self.GetTextRange(cpos, cpos + repeat)
-                    tmp = tmp.split(self.GetEOLChar())
-                    end = cpos + len(tmp[0])
-                else:
-                    tmp = self.GetTextRange(cpos - repeat, cpos)
-                    tmp = tmp.split(self.GetEOLChar())
-                    end = cpos - len(tmp[-1])
-                    tmp = end
-                    end = cpos
-                    cpos = tmp
-
-                if cpos == self.GetLineEndPosition(cline):
-                    self.SetSelection(cpos - 1, cpos)
-                else:
-                    self.SetSelection(cpos, end)
-                repeat = 1
-            elif rcmd == u'O':
-                kargs['before'] = True
-
-            self.BeginUndoAction()
-            if rcmd in u'CD': # Cut line right
-                self.SetSelection(cpos, 
-                                  self.GetLineEndPosition(cline + (repeat - 1)))
-                self.Cut()
-            elif rcmd == u'J':
-                self.SetTargetStart(cpos)
-                if repeat == 1:
-                    repeat = 2
-                self.SetTargetEnd(self.PositionFromLine(cline + repeat - 1))
-                self.LinesJoin()
-            elif rcmd == u'G':
-                if repeat == 1 and '1' not in cmd:
-                    repeat = self.GetLineCount()
-                self.GotoLine(repeat - 1)
-            elif rcmd == u'+':
-                self.GotoIndentPos(cline + repeat)
-            elif rcmd == u'-':
-                self.GotoIndentPos(cline - repeat)
-            elif rcmd == u'|':
-                self.GotoColumn(repeat - 1)
-            else:
-                if not cmd_map.has_key(rcmd):
-                    return
-                run = cmd_map[rcmd]
-                for count in xrange(repeat):                
-                    run(*args, **kargs)
-            if rcmd == u'p':
-                if newline:
-                    self.GotoIndentPos(cline + repeat)
-                else:
-                    self.GotoPos(cpos + 1)
-            elif rcmd == u'P':
-                if newline:
-                    self.GotoIndentPos(cline)
-                else:
-                    self.GotoPos(cpos)
-#             elif rcmd == u'u':
-#                 self.GotoPos(cpos)
-            elif rcmd in u'CoOs':
-                self.SetViNormalMode(False)
-            self.EndUndoAction()
-            self._vi['last'] = cmd
-            self._vi['cmdcache'] = u''
-        # 2 key commands
-        elif re.match(VI_DOUBLE_P1, cmd) or \
-             re.match(VI_DOUBLE_P2, cmd) or \
-             re.match(re.compile('[cdy]0'), cmd):
-            if re.match(re.compile('[cdy]0'), cmd):
-                rcmd = cmd
-            else:
-                rcmd = re.sub(NUM_PAT, u'', cmd)
-            repeat = re.subn(re.compile(VI_DCMD_RIGHT), u'', cmd, 2)[0]
-            if repeat == u'':
-                repeat = 1
-            else:
-                repeat = int(repeat)
-
-            if rcmd[-1] not in u'bBeEGhHlLMwW$|{}0':
-                self.GotoLine(cline)
-                if repeat != 1 or rcmd not in u'>><<':
-                    self.SetSelectionStart(self.GetCurrentPos())
-                    self.SetSelectionEnd(self.PositionFromLine(cline + repeat))
-            else:
-                self.SetAnchor(self.GetCurrentPos())
-                mcmd = { u'b' : self.WordPartLeftExtend,
-                         u'B' : self.WordLeftExtend,
-                         u'e' : self.WordPartRightEndExtend,
-                         u'E' : self.WordRightEndExtend,
-                         u'h' : self.CharLeftExtend,
-                         u'l' : self.CharRightExtend,
-                         u'w' : self.WordPartRightExtend,
-                         u'W' : self.WordRightExtend,
-                         u'{' : self.ParaUpExtend,
-                         u'}' : self.ParaDownExtend}
-
-                if u'$' in rcmd:
-                    pos = self.GetLineEndPosition(cline + repeat - \
-                                                  len(self.GetEOLChar()))
-                    self.SetCurrentPos(pos)
-                elif u'G' in rcmd:
-                    if repeat == 0: # invalid cmd
-                        self._vi['cmdcache'] = u''
-                        return
-                    if repeat == 1 and u'1' not in cmd: # Default eof
-                        self.SetAnchor(self.GetLineEndPosition(cline - 1))
-                        repeat = self.GetLength()
-                    elif repeat < cline + 1:
-                        self.SetAnchor(self.PositionFromLine(cline + 1))
-                        repeat = self.PositionFromLine(repeat - 1)
-                        cline = self.LineFromPosition(repeat) - 1
-                    elif repeat > cline:
-                        self.SetAnchor(self.GetLineEndPosition(cline - 1))
-                        if cline == 0:
-                            repeat = self.PositionFromLine(repeat)
-                        else:
-                            repeat = self.GetLineEndPosition(repeat - 1)
-                    else:
-                        self.SetAnchor(self.PositionFromLine(cline))
-                        repeat = self.PositionFromLine(cline + 1)
-                    self.SetCurrentPos(repeat)
-                elif rcmd[-1] in u'HM':
-                    fline = self.GetFirstVisibleLine()
-                    lline = self.GetLastVisibleLine()
-
-                    if u'M' in rcmd:
-                        repeat = self.GetMiddleVisibleLine() + 1
-                    elif fline + repeat > lline:
-                        repeat = lline
-                    else:
-                        repeat = fline + repeat
-
-                    if repeat > cline:
-                        self.SetAnchor(self.PositionFromLine(cline))
-                        self.SetCurrentPos(self.PositionFromLine(repeat))
-                    else:
-                        self.SetAnchor(self.PositionFromLine(repeat - 1))
-                        self.SetCurrentPos(self.PositionFromLine(cline + 1))
-                elif u'L' in rcmd:
-                    fline = self.GetFirstVisibleLine()
-                    lline = self.GetLastVisibleLine()
-                    if lline - repeat < fline:
-                        repeat = fline
-                    else:
-                        repeat = lline - repeat
-
-                    if repeat < cline:
-                        self.SetAnchor(self.PositionFromLine(cline))
-                        self.SetCurrentPos(self.PositionFromLine(repeat))
-                    else:
-                        self.SetAnchor(self.PositionFromLine(cline))
-                        self.SetCurrentPos(self.PositionFromLine(repeat + 2))
-                elif u'|' in rcmd:
-                    if repeat == 1 and u'1' not in cmd:
-                        repeat = 0
-                    self.SetCurrentCol(repeat)
-                elif rcmd[-1] == u'0':
-                    self.SetCurrentCol(0)
-                else:
-                    doit = mcmd[rcmd[-1]]
-                    for x in xrange(repeat):
-                        doit()
-
-            self.BeginUndoAction()
-            if re.match(re.compile('c|c' + VI_DCMD_RIGHT), rcmd):
-                if rcmd == u'cc':
-                    self.SetSelectionEnd(self.GetSelectionEnd() - \
-                                         len(self.GetEOLChar()))
-                self.Cut()
-                self.SetViNormalMode(False)
-            elif re.match(re.compile('d|d' + VI_DCMD_RIGHT), rcmd):
-                self.Cut()
-            elif re.match(re.compile('y|y' + VI_DCMD_RIGHT), rcmd):
-                self.Copy()
-                self.GotoPos(cpos)
-            elif rcmd == u'<<':
-                self.BackTab()
-            elif rcmd == u'>>':
-                self.Tab()
-            else:
-                pass
-            self.EndUndoAction()
-            if rcmd in '<<>>' or rcmd[-1] == u'G':
-                self.GotoIndentPos(cline)
-            self._vi['last'] = cmd
-            self._vi['cmdcache'] = u''
-        else:
-            pass
-
-        # Update status bar
-        if mw and self._vi['normal']:
-            evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
-                                       'NORMAL  %s' % self._vi['cmdcache'],
-                                        ed_glob.SB_BUFF)
-            wx.PostEvent(self.GetTopLevelParent(), evt)
-        
     def FoldingOnOff(self, switch=None):
         """Turn code folding on and off
         @keyword switch: force a particular setting
@@ -1878,10 +1575,12 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """Load the file at the given path into the buffer. Returns
         True if no errors and False otherwise. To retrieve the errors
         check the last error that was set in the file object returned by
-        L{GetDocPointer}.
+        L{GetDocument}.
         @param path: path to file
 
         """
+        # Post notification that a file load is starting
+        ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENING, path)
         self.file.SetPath(path)
         txt = self.file.Read()
         if txt is not None:
@@ -2020,7 +1719,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         except KeyError:
             self.LOG("[ed_stc][err] No Keywords Data Found")
             keywords = []
-       
+
         try:
             synspec = syn_data[syntax.SYNSPEC]
         except KeyError:
@@ -2077,7 +1776,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         kwlist.sort()                              # Sort into alphbetical order
         self._code['keywords'] = " ".join(kwlist)  # Put back into a string
         return True
- 
+
     def SetSyntax(self, syn_lst):
         """Sets the Syntax Style Specs from a list of specifications
         @param syn_lst: [(STYLE_ID, "STYLE_TYPE"), (STYLE_ID2, "STYLE_TYPE2)]
@@ -2128,7 +1827,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     #---- Style Function Definitions ----#
     def RefreshStyles(self):
-        """Refreshes the colorization of the window by reloading any 
+        """Refreshes the colorization of the window by reloading any
         style tags that may have been modified.
         @postcondition: all style settings are refreshed in the control
 
