@@ -21,8 +21,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 51397 2008-01-27 07:24:10Z CJP $"
-__revision__ = "$Revision: 51397 $"
+__svnid__ = "$Id: ed_theme.py 51749 2008-02-13 07:59:12Z CJP $"
+__revision__ = "$Revision: 51749 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -254,13 +254,14 @@ class TangoTheme(plugin.Plugin):
             ed_glob.CONFIG['THEME_DIR'] = theme
 
         if mime:
-            path = ed_glob.CONFIG['THEME_DIR'] + util.GetPathChar() + \
-                   Profile_Get('ICONS') + util.GetPathChar() + \
-                   u'mime' + util.GetPathChar()
+            path = os.path.join(ed_glob.CONFIG['THEME_DIR'],
+                                Profile_Get('ICONS'), u'mime')
         else:
-            path = ed_glob.CONFIG['THEME_DIR'] + util.GetPathChar() + \
-                   Profile_Get('ICONS') + util.GetPathChar() + \
-                   clients.get(client, u"menu") + util.GetPathChar()
+            path = os.path.join(ed_glob.CONFIG['THEME_DIR'],
+                                Profile_Get('ICONS'),
+                                clients.get(client, u"menu"))
+
+        path += os.sep
 
         if os.path.exists(path):
             return path
