@@ -15,8 +15,8 @@ SUMMARY: Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 51589 2008-02-08 07:58:51Z CJP $"
-__revision__ = "$Revision: 51589 $"
+__svnid__ = "$Id: ed_txt.py 52380 2008-03-08 10:30:35Z CJP $"
+__revision__ = "$Revision: 52380 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -210,7 +210,8 @@ class EdFile(object):
                     if enc:
                         self._magic['comment'] = enc
                 else:
-                    self.bom = BOM.get(enc, None)
+                    Log("[ed_txt][info] File Has %s BOM" % enc)
+                    self.bom = unicode(BOM.get(enc, None), enc)
 
             if enc is not None:
                 self.encoding = enc
@@ -220,6 +221,8 @@ class EdFile(object):
                 txt = reader.read()
                 reader.close()
             except Exception, msg:
+                Log("[ed_txt][err] Error while reading with %s" % self.encoding)
+                Log("[ed_txt][err] %s" % msg)
                 self.last_err = str(msg)
                 self.Close()
                 if self._magic['comment']:
@@ -231,13 +234,25 @@ class EdFile(object):
                     raise UnicodeDecodeError, msg
 
             if self.bom is not None:
-                txt = txt.replace(self.bom, '', 1)
+                Log("[ed_txt][info] Stripping %s BOM from text" % self.encoding)
+                txt = txt.replace(self.bom, u'', 1)
 
             Log("[ed_txt][info] Decoded %s with %s" % (self.path, self.encoding))
             return txt
         else:
             raise ReadError, self.last_err
 
+    def ResetAll(self):
+        """Reset all attributes of this file"""
+        self._handle = None
+        self._magic = dict(comment=None, bad=False)
+        self.encoding = DEFAULT_ENCODING
+        self.open = False
+        self.path = ''
+        self.bom = None
+        self.modtime = 0
+        self.last_err = None
+
     def SetEncoding(self, enc):
         """Explicitly set/change the encoding of the file
         @param enc: encoding to change to
@@ -277,6 +292,7 @@ class EdFile(object):
         tbuff = StringIO(value)
         enc = CheckMagicComment([ tbuff.readline() for x in range(2) ])
         tbuff.close()
+        del tbuff
 
         # Update encoding if necessary
         if enc is not None:
@@ -284,9 +300,10 @@ class EdFile(object):
 
         # Open and write the file
         if self.DoOpen('wb'):
-            Log("[ed_txt][info] Opened %s, wrtiting as %s" % (self.path, self.encoding))
-            writer = codecs.getwriter(self.Encoding)(self._handle)
+            Log("[ed_txt][info] Opened %s, writing as %s" % (self.path, self.encoding))
+            writer = codecs.getwriter(self.encoding)(self._handle)
             if self.HasBom():
+                Log("[ed_txt][info] Adding BOM back to text")
                 value = self.bom + value
             writer.write(value)
             writer.close()
@@ -342,7 +359,7 @@ def DecodeString(string, encoding=None):
 
     if isinstance(string, types.UnicodeType):
         try:
-            rtxt = codecs.getdecoder(encoding)(string)
+            rtxt = codecs.getdecoder(encoding)(string)[0]
         except Exception, msg:
             Log("[ed_txt][err] DecodeString with %s failed" % encoding)
             Log("[ed_txt][err] %s" % msg)
@@ -365,7 +382,7 @@ def EncodeString(string, encoding=None):
 
     if isinstance(string, types.UnicodeType):
         try:
-            rtxt = codecs.getencoder(encoding)(string)
+            rtxt = codecs.getencoder(encoding)(string)[0]
         except LookupError:
             rtxt = string
         return rtxt
