@@ -1,22 +1,11 @@
-############################################################################
-#    Copyright (C) 2007 Cody Precord                                       #
-#    cprecord@editra.org                                                   #
-#                                                                          #
-#    Editra is free software; you can redistribute it and#or modify        #
-#    it under the terms of the GNU General Public License as published by  #
-#    the Free Software Foundation; either version 2 of the License, or     #
-#    (at your option) any later version.                                   #
-#                                                                          #
-#    Editra is distributed in the hope that it will be useful,             #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-#    GNU General Public License for more details.                          #
-#                                                                          #
-#    You should have received a copy of the GNU General Public License     #
-#    along with this program; if not, write to the                         #
-#    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
-############################################################################
+###############################################################################
+# Name: generator.py                                                          #
+# Purpose: Utility classes for creating various formatted plain text          #
+#          from the contents of a EdStc text buffer (i.e HTML, LaTeX, Rtf)    #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Licence: wxWindows Licence                                                  #
+###############################################################################
 
 """
 #--------------------------------------------------------------------------#
@@ -25,18 +14,19 @@
 # LANGUAGE: Python                                                         #
 # SUMMARY:                                                                 #
 #    Provides various methods and classes for generating code and          #
-# transforming code to different formats such as html, latex, rtf          #
+# transforming code to different formats such as html, latex, rtf with all #
+# the styling and formating intact from how the view is shown in the       #
+# editor.                                                                  #
+#                                                                          #
+#    It also provides a plugin interface that allows for plugins that wish #
+# to provide similar services for manipulating and transforming text.      #
 #                                                                          #
-# METHODS:                                                                 #
-#
-#
-#
 #--------------------------------------------------------------------------#
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: generator.py 525 2007-09-26 07:50:18Z CodyPrecord $"
-__revision__ = "$Revision: 525 $"
+__cvsid__ = "$Id: generator.py 51110 2008-01-08 15:03:38Z CJP $"
+__revision__ = "$Revision: 51110 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -68,7 +58,7 @@ class GeneratorI(plugin.Interface):
         an associated file extention to use for setting highlighting
         if available and the second item is the string of the new document.
         @param stc: reference to an an stc defined in ed_stc.py
-        @see: L{ed_stc.py}
+        @see: L{ed_stc}
 
         """
         pass
@@ -105,17 +95,17 @@ class Generator(plugin.Plugin):
         @type menu: wx.Menu
 
         """
-        log = wx.GetApp().GetLog()
         menu_items = list()
         for observer in self.observers:
             try:
                 menu_i = observer.GetMenuEntry(menu)
                 if menu_i:
-                    menu_items.append((menu_i.GetLabel(), menu_i))
+                    menu_items.append((menu_i.GetItemLabel(), menu_i))
             except Exception, msg:
-                log("[generator][err] %s" % str(msg))
+                util.Log("[generator][err] %s" % str(msg))
+
         menu_items.sort()
-        genmenu = ed_menu.ED_Menu()
+        genmenu = ed_menu.EdMenu()
         for item in menu_items:
             genmenu.AppendItem(item[1])
         menu.AppendMenu(ed_glob.ID_GENERATOR, _("Generator"), genmenu,
@@ -126,7 +116,7 @@ class Generator(plugin.Plugin):
         generator id and contents of the given ED_STC text control.
         @param e_id: event id originating from menu entry
         @param txt_ctrl: reference document to generate from
-        @type txt_ctrl: EDSTC
+        @type txt_ctrl: EditraStc
         @return: the generated text
         @rtype: string
         
@@ -136,8 +126,7 @@ class Generator(plugin.Plugin):
         for observer in self.observers:
             if observer.GetId() == e_id:
                 gentext = observer.Generate(txt_ctrl)
-        wx.GetApp().GetLog()("[generator][info] Generation time %f" % \
-                                                        (time.time() - start))
+        util.Log("[generator][info] Generation time %f" % (time.time() - start))
         return gentext
 
 #--------------------------------------------------------------------------#
@@ -166,7 +155,7 @@ class Html(plugin.Plugin):
 
     def __str__(self):
         """Returns the string of html
-        @return string version of html object
+        @return: string version of html object
 
         """
         style = "<style type=\"text/css\">\n%s</style>"
@@ -207,7 +196,8 @@ class Html(plugin.Plugin):
                "<meta name=\"Generator\" content=\"Editra/%s\">\n" \
                "<meta http-equiv=\"content-type\" content=\"text/html; " \
                "charset=utf-8\">" \
-               "\n</head>" % (self.stc.filename, ed_glob.VERSION)
+               "\n</head>" % (util.GetFileName(self.stc.GetFileName()), 
+                              ed_glob.VERSION)
 
     def GenerateBody(self):
         """Generates the body of the html from the stc's content. To do
@@ -338,7 +328,7 @@ class CssItem(object):
         @param class_tag: StyleItem tag name
         @param style_item: style item to convert to css
         @type style_item: ed_style.StyleItem
-        @see: L{ed_style.py}
+        @see: L{ed_style}
 
         """
         object.__init__(self)
