@@ -22,8 +22,8 @@ Intefaces:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: iface.py 51588 2008-02-08 07:58:20Z CJP $"
-__revision__ = "$Revision: 51588 $"
+__svnid__ = "$Id: iface.py 51989 2008-02-22 10:19:20Z CJP $"
+__revision__ = "$Revision: 51989 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -282,7 +282,7 @@ class Shelf(plugin.Plugin):
             if mitem.GetId() == ed_glob.ID_PERSPECTIVES:
                 break
 
-        view.InsertMenu(pos + 1, ed_glob.ID_SHELF, SHELF_NAME, 
+        view.InsertMenu(pos + 1, ed_glob.ID_SHELF, _("Shelf"), 
                         menu, _("Put an item on the Shelf"))
         for item in menu.GetMenuItems():
             if item.IsSeparator():
