@@ -6,13 +6,16 @@
 # License: wxWindows License                                                  #
 ###############################################################################
 
+"""Editra Project information module"""
+
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: info.py 51605 2008-02-08 15:06:51Z CJP $"
-__revision__ = "$Revision: 51605 $"
+__svnid__ = "$Id: info.py 52439 2008-03-11 08:53:25Z CJP $"
+__revision__ = "$Revision: 52439 $"
 
 
 AUTHOR = 'Cody Precord'
-VERSION = '0.2.65'
+VERSION = '0.2.90'
 PROG_NAME = 'Editra'
 HOME_PAGE = "http://editra.org"
+I18N_PAGE = "https://translations.launchpad.net/editra/trunk/+pots/editra"
 CONTACT_MAIL = "staff@editra.org"
