@@ -19,8 +19,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: perspective.py 51096 2008-01-08 08:03:46Z CJP $"
-__revision__ = "$Revision: 51096 $"
+__cvsid__ = "$Id: perspective.py 51436 2008-01-29 10:11:39Z CJP $"
+__revision__ = "$Revision: 51436 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -86,8 +86,12 @@ class PerspectiveManager(object):
         # Restore the managed windows previous position and alpha
         # preferences if they are available.
         self._window.SetTransparent(Profile_Get('ALPHA', default=255))
-        if Profile_Get('SET_WPOS') and Profile_Get('WPOS', "size_tuple", False):
-            self._window.SetPosition(Profile_Get('WPOS'))
+        pos = Profile_Get('WPOS', "size_tuple", False)
+        if Profile_Get('SET_WPOS') and pos:
+            # Ensure window is on screen
+            if pos[0] < 0 or pos[1] < 0:
+                pos = (0, 0)
+            self._window.SetPosition(pos)
 
         # Event Handlers
         self._window.Bind(wx.EVT_MENU, self.OnPerspectiveMenu)
@@ -319,10 +323,10 @@ class PerspectiveManager(object):
         if self._viewset.has_key(name):
 
             if name == AUTO_PERSPECTIVE:
-                self._viewset[name] = self._viewset[self._currview]
-            else:
-                self._mgr.LoadPerspective(self._viewset[name])
-                self._mgr.Update()
+                self._viewset[AUTO_PERSPECTIVE] = self._viewset[self._currview]
+
+            self._mgr.LoadPerspective(self._viewset[name])
+            self._mgr.Update()
 
             self._currview = name
             self.SavePerspectives()
