@@ -1,39 +1,26 @@
 ###############################################################################
-#    Copyright (C) 2007 Editra Development Team                               #
-#    staff@editra.org                                                         #
-#                                                                             #
-#    This program is free software; you can redistribute it and#or modify     #
-#    it under the terms of the GNU General Public License as published by     #
-#    the Free Software Foundation; either version 2 of the License, or        #
-#    (at your option) any later version.                                      #
-#                                                                             #
-#    This program is distributed in the hope that it will be useful,          #
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of           #
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            #
-#    GNU General Public License for more details.                             #
-#                                                                             #
-#    You should have received a copy of the GNU General Public License        #
-#    along with this program; if not, write to the                            #
-#    Free Software Foundation, Inc.,                                          #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                #
+# Name: php.py                                                                #
+# Purpose: Define PHP syntax for highlighting and other features              #
+# Author: Cody Precord <cprecord@editra.org>                                  #
+# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#-----------------------------------------------------------------------------#
-# FILE: php.py                                                                #
-# AUTHOR: Cody Precord                                                        #
-#                                                                             #
-# @summary: Lexer configuration module for PHP.                               #
-#                                                                             #
-#-----------------------------------------------------------------------------#
+FILE: php.py                                                                
+AUTHOR: Cody Precord                                                        
+                                                                         
+@summary: Lexer configuration module for PHP.                               
+                                                                         
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: php.py 268 2007-07-07 14:37:37Z CodyPrecord $"
-__revision__ = "$Revision: 268 $"
+__svnid__ = "$Id: php.py 52279 2008-03-03 09:00:42Z CJP $"
+__revision__ = "$Revision: 52279 $"
 
 #-----------------------------------------------------------------------------#
 # Dependancies
+import synglob
 import html
 #-----------------------------------------------------------------------------#
 
@@ -418,33 +405,45 @@ def Keywords(lang_id=0):
     @param lang_id: used to select specific subset of keywords
 
     """
-    # Support Embedded HTML highlighting
-    keywords = HTML_KEYWORDS
-    keywords.append((4, PHP_KEYWORDS))
-    return keywords
+    if lang_id == synglob.ID_LANG_PHP:
+        # Support Embedded HTML highlighting
+        keywords = HTML_KEYWORDS
+        keywords.append((4, PHP_KEYWORDS))
+        return keywords
+    else:
+        return list()
 
 def SyntaxSpec(lang_id=0):
     """Syntax Specifications
     @param lang_id: used for selecting a specific subset of syntax specs
 
     """
-    return html.SYNTAX_ITEMS + SYNTAX_ITEMS
+    if lang_id == synglob.ID_LANG_PHP:
+        return html.SYNTAX_ITEMS + SYNTAX_ITEMS
+    else:
+        return list()
 
 def Properties(lang_id=0):
     """Returns a list of Extra Properties to set
     @param lang_id: used to select a specific set of properties
 
     """
-    return [("fold", "1"), ("fold.html", "1")]
+    if lang_id == synglob.ID_LANG_PHP:
+        return [html.FOLD, html.FLD_HTML]
+    else:
+        return list()
 
 def CommentPattern(lang_id=0):
     """Returns a list of characters used to comment a block of code
     @param lang_id: used to select a specific subset of comment pattern(s)
-    @todo: currently unsupported because of difficulties due to having
-           other inline code such as html that require different
+    @note: assuming pure php code for comment character(s)
 
     """
-    return list()
+    if lang_id == synglob.ID_LANG_PHP:
+        return [u'//']
+    else:
+        return list()
+
 #---- End Required Functions ----#
 
 #---- Syntax Modules Internal Functions ----#
@@ -456,5 +455,3 @@ def KeywordString(option=0):
     return PHP_KEYWORDS
 
 #---- End Syntax Modules Internal Functions ----#
-
-#---- Module Helper Functions ----#
