@@ -2,30 +2,28 @@
 # Name: synglob.py                                                            #
 # Purpose: Acts as a registration point for all supported languages.          #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#-----------------------------------------------------------------------------#
-# FILE: synglob.py                                                            #
-# AUTHOR: Cody Precord                                                        #
-#                                                                             #
-# SUMMARY:                                                                    #
-# Provides configuration and basic API functionality to all the syntax        #
-# modules. It also acts more or less as a configuration file for the syntax   #
-# managment code.                                                             #
-#                                                                             #
-#-----------------------------------------------------------------------------#
+FILE: synglob.py
+AUTHOR: Cody Precord
+
+SUMMARY:
+Provides configuration and basic API functionality to all the syntax
+modules. It also acts  as a configuration file for the syntax management code.
+When support for a new languages is added it must have a registration entry in
+the below L{LANG_MAP} dictionary in order to be loadable by the syntax module.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synglob.py 51489 2008-02-01 10:17:24Z CJP $"
-__revision__ = "$Revision: 51489 $"
+__svnid__ = "$Id: synglob.py 52177 2008-02-28 12:02:25Z CJP $"
+__revision__ = "$Revision: 52177 $"
 
 #-----------------------------------------------------------------------------#
 # Dependencies
-import wx
 import wx.stc as stc
 
 # The language identifiers and the EXT_MAP have been moved out of this
@@ -39,6 +37,7 @@ from synextreg import *
 LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_ADA    : (ID_LANG_ADA,    stc.STC_LEX_ADA,      'ada'),
             LANG_APACHE : (ID_LANG_APACHE, stc.STC_LEX_CONF,     'apache'),
+            LANG_AS     : (ID_LANG_AS,     stc.STC_LEX_CPP,      'actionscript'),
             LANG_BASH   : (ID_LANG_BASH,   stc.STC_LEX_BASH,     'sh'),
             LANG_BATCH  : (ID_LANG_BATCH,  stc.STC_LEX_BATCH,    'batch'),
             LANG_BOO    : (ID_LANG_BOO,    stc.STC_LEX_PYTHON,   'boo'),
@@ -78,6 +77,7 @@ LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_MSSQL  : (ID_LANG_MSSQL,  stc.STC_LEX_MSSQL,    'mssql'),
             LANG_NASM   : (ID_LANG_NASM,   stc.STC_LEX_ASM,      'nasm'),
             LANG_NSIS   : (ID_LANG_NSIS,   stc.STC_LEX_NSIS,     'nsis'),
+            LANG_OBJC   : (ID_LANG_OBJC,   stc.STC_LEX_CPP,      'cpp'),
             LANG_OCTAVE : (ID_LANG_OCTAVE, stc.STC_LEX_OCTAVE,   'matlab'),
             LANG_PASCAL : (ID_LANG_PASCAL, stc.STC_LEX_PASCAL,   'pascal'),
             LANG_PERL   : (ID_LANG_PERL,   stc.STC_LEX_PERL,     'perl'),
@@ -88,6 +88,7 @@ LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_PS     : (ID_LANG_PS,     stc.STC_LEX_PS,       'postscript'),
             LANG_PYTHON : (ID_LANG_PYTHON, stc.STC_LEX_PYTHON,   'python'),
             LANG_RUBY   : (ID_LANG_RUBY,   stc.STC_LEX_RUBY,     'ruby'),
+            LANG_SCHEME : (ID_LANG_SCHEME, stc.STC_LEX_LISP,     'lisp'),
             LANG_SQL    : (ID_LANG_SQL,    stc.STC_LEX_SQL,      'sql'),
             LANG_ST     : (ID_LANG_ST,     stc.STC_LEX_SMALLTALK, 'smalltalk'),
             LANG_TCL    : (ID_LANG_TCL,    stc.STC_LEX_TCL,      'tcl'),
@@ -99,39 +100,21 @@ LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_YAML   : (ID_LANG_YAML,   stc.STC_LEX_YAML,     'yaml')
             }
 
-# Maps language ID's to File Types
+# Dynamically finds the language description string that matches the given
+# language id.
 # Used when manually setting lexer from a menu/dialog
-# TODO maybe dynamically generate this on the fly to remove the need
-#      to update it for each new language.
-ID_MAP = {ID_LANG_68K    : LANG_68K,    ID_LANG_ADA   : LANG_ADA,
-          ID_LANG_APACHE : LANG_APACHE, ID_LANG_ASM   : LANG_ASM,
-          ID_LANG_BASH   : LANG_BASH,   ID_LANG_BATCH : LANG_BATCH,
-          ID_LANG_BOO    : LANG_BOO,    ID_LANG_C     : LANG_C,
-          ID_LANG_CAML  : LANG_CAML,    ID_LANG_COLDFUSION : LANG_COLDFUSION,
-          ID_LANG_CPP    : LANG_CPP,    ID_LANG_CSH   : LANG_CSH, 
-          ID_LANG_CSS    : LANG_CSS,    ID_LANG_D     : LANG_D,
-          ID_LANG_DIFF   : LANG_DIFF,   ID_LANG_DOT    : LANG_DOT,
-          ID_LANG_EDJE   : LANG_EDJE,   ID_LANG_EIFFEL : LANG_EIFFEL,
-          ID_LANG_ERLANG : LANG_ERLANG, ID_LANG_ESS    : LANG_ESS,
-          ID_LANG_F77    : LANG_F77,    ID_LANG_F95   : LANG_F95,
-          ID_LANG_FERITE : LANG_FERITE, ID_LANG_FLAGSHIP : LANG_FLAGSHIP,
-          ID_LANG_GUI4CLI : LANG_GUI4CLI, ID_LANG_HASKELL : LANG_HASKELL,
-          ID_LANG_HAXE   : LANG_HAXE,    ID_LANG_HTML  : LANG_HTML,
-          ID_LANG_INNO   : LANG_INNO,   ID_LANG_JAVA  : LANG_JAVA,
-          ID_LANG_JS     : LANG_JS,     ID_LANG_KIX   : LANG_KIX,
-          ID_LANG_KSH    : LANG_KSH,    ID_LANG_LATEX : LANG_LATEX,
-          ID_LANG_LISP   : LANG_LISP,   ID_LANG_LOUT  : LANG_LOUT,
-          ID_LANG_LUA    : LANG_LUA,    ID_LANG_MAKE  : LANG_MAKE,
-          ID_LANG_MASM   : LANG_MASM,   ID_LANG_MATLAB : LANG_MATLAB,
-          ID_LANG_MSSQL  : LANG_MSSQL,  ID_LANG_NASM  : LANG_MASM,
-          ID_LANG_NSIS   : LANG_NSIS,   ID_LANG_OCTAVE : LANG_OCTAVE,
-          ID_LANG_PASCAL : LANG_PASCAL, ID_LANG_PERL   : LANG_PERL,
-          ID_LANG_PHP    : LANG_PHP,    ID_LANG_PIKE   : LANG_PIKE,
-          ID_LANG_PROPS  : LANG_PROPS,  ID_LANG_PS     : LANG_PS,
-          ID_LANG_PLSQL  : LANG_PLSQL,  ID_LANG_PYTHON : LANG_PYTHON,
-          ID_LANG_RUBY   : LANG_RUBY,   ID_LANG_SQL    : LANG_SQL,
-          ID_LANG_ST     : LANG_ST,     ID_LANG_VB     : LANG_VB,
-          ID_LANG_VERILOG : LANG_VERILOG, ID_LANG_VHDL : LANG_VHDL,
-          ID_LANG_TCL    : LANG_TCL,    ID_LANG_TXT    : LANG_TXT,
-          ID_LANG_XML    : LANG_XML,    ID_LANG_YAML   : LANG_YAML
-}
+def GetDescriptionFromId(lang_id):
+    """Get the programming languages description string from the given
+    lanugage id. If no correspoding language is found the plain text
+    description is returned.
+    @param lang_id: Language Identifier ID
+    @note: requires that all languages are defined in ID_LANG_NAME, LANG_NAME
+           pairs to work properly.
+
+    """
+    rval = LANG_TXT
+    for key, val in globals().iteritems():
+        if val == lang_id and key.startswith('ID_LANG'):
+            rval = globals().get(key[3:], globals()['LANG_TXT'])
+            break
+    return rval
