@@ -7,29 +7,29 @@
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: util.py                                                            #
-# LANGUAGE: Python                                                         #
-#                                                                          #
-# SUMMARY:                                                                 #
-# This file contains various helper functions and utilities that the       #
-# program uses. Basically a random library of misfit functions.	           #
-#                                                                          #
-#--------------------------------------------------------------------------#
+FILE: util.py
+LANGUAGE: Python
+
+SUMMARY:
+This file contains various helper functions and utilities that the
+program uses. Basically a random library of misfit functions.
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 51502 2008-02-02 11:58:14Z CJP $"
-__revision__ = "$Revision: 51502 $"
+__svnid__ = "$Id: util.py 52480 2008-03-14 08:01:27Z CJP $"
+__revision__ = "$Revision: 52480 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+import stat
 import codecs
 import urllib2
 import wx
+
+# Editra Libraries
 import ed_glob
 import ed_event
 import ed_crypt
@@ -51,7 +51,7 @@ class DropTargetFT(wx.PyDropTarget):
         """
         wx.PyDropTarget.__init__(self)
         self.window = window
-        self._data = dict(data=None, fdata=None, tdata=None, 
+        self._data = dict(data=None, fdata=None, tdata=None,
                           tcallb=textcallback, fcallb=filecallback)
         self._tmp = None
         self._lastp = None
@@ -75,7 +75,7 @@ class DropTargetFT(wx.PyDropTarget):
                 longest = ext
 
         cords = [ (0, x * longest[1]) for x in xrange(len(txt)) ]
-        mdc = wx.MemoryDC(wx.EmptyBitmap(longest[0] + 5, 
+        mdc = wx.MemoryDC(wx.EmptyBitmap(longest[0] + 5,
                                          longest[1] * len(txt), 32))
         mdc.SetBackgroundMode(wx.TRANSPARENT)
         mdc.SetTextForeground(stc.GetDefaultForeColour())
@@ -209,18 +209,55 @@ class DropTargetFT(wx.PyDropTarget):
 #---- End FileDropTarget ----#
 
 #---- Misc Common Function Library ----#
-def SetClipboardText(txt):
-    """Copies text to the clipboard
-    @param txt: text to put in clipboard
+# Used for holding the primary selection on mac/msw
+FAKE_CLIPBOARD = None
+
+def GetClipboardText():
+    """Get the primary selection from the clipboard if there is one
+    @return: str or None
 
     """
+    if wx.Platform == '__WXGTK__':
+        wx.TheClipboard.UsePrimarySelection(True)
+    else:
+        # Fake the primary selection on mac/msw
+        global FAKE_CLIPBOARD
+        return FAKE_CLIPBOARD
+    text_obj = wx.TextDataObject()
+    rtxt = None
+    if wx.TheClipboard.Open():
+        if wx.TheClipboard.GetData(text_obj):
+            rtxt = text_obj.GetText()
+        wx.TheClipboard.Close()
+
+    if wx.Platform == '__WXGTK__':
+        wx.TheClipboard.UsePrimarySelection(False)
+    return rtxt
+
+def SetClipboardText(txt, primary=False):
+    """Copies text to the clipboard
+    @param txt: text to put in clipboard
+    @keyword primary: Set txt as primary selection (x11)
+
+    """
+    if primary and wx.Platform == '__WXGTK__':
+        wx.TheClipboard.UsePrimarySelection(True)
+    else:
+        # Fake the primary selection on mac/msw
+        global FAKE_CLIPBOARD
+        FAKE_CLIPBOARD = txt
+        return True
+
     data_o = wx.TextDataObject()
     data_o.SetText(txt)
     if wx.TheClipboard.Open():
         wx.TheClipboard.SetData(data_o)
         wx.TheClipboard.Close()
-        return 1
-    return 0
+        if primary and wx.Platform == '__WXGTK__':
+            wx.TheClipboard.UsePrimarySelection(False)
+        return True
+    else:
+        return False
 
 def FilterFiles(file_list):
     """Filters a list of paths and returns a list of paths
@@ -258,7 +295,7 @@ def GetFileReader(file_name, enc='utf-8'):
     supplied file name. It returns a file reader using the encoding
     (enc) which defaults to utf-8. If lookup of the reader fails on
     the host system it will return an ascii reader.
-    If there is an error in creating the file reader the function 
+    If there is an error in creating the file reader the function
     will return a negative number.
     @param file_name: name of file to get a reader for
     @keyword enc: encoding to use for reading the file
@@ -281,9 +318,9 @@ def GetFileReader(file_name, enc='utf-8'):
 def GetFileWriter(file_name, enc='utf-8'):
     """Returns a file stream writer object for reading the
     supplied file name. It returns a file writer in the supplied
-    encoding if the host system supports it other wise it will return 
+    encoding if the host system supports it other wise it will return
     an ascii reader. The default will try and return a utf-8 reader.
-    If there is an error in creating the file reader the function 
+    If there is an error in creating the file reader the function
     will return a negative number.
     @param file_name: path of file to get writer for
     @keyword enc: encoding to write text to file with
@@ -301,15 +338,6 @@ def GetFileWriter(file_name, enc='utf-8'):
         writer = file_h
     return writer
 
-def GetPathChar():
-    """Returns the path character for the OS running the program
-    @return: character used as file path separator
-    """
-    if wx.Platform == '__WXMSW__':
-        return u"\\"
-    else:
-        return u"/"
-
 def GetUniqueName(path, name):
     """Make a file name that will be unique in case a file of the
     same name already exists at that path.
@@ -340,27 +368,52 @@ def GetPathName(path):
     @param path: full path to get base of
 
     """
-    pieces = os.path.split(path)
-    return pieces[0]
+    return os.path.split(path)[0]
+
+def GetFileManagerCmd():
+    """Get the file manager open command for the current os. Under linux
+    it will check for nautilus and konqueror and return which one it finds
+    first or 'nautilus' (Gnome) if it finds neither.
+    @return: string command
+
+    """
+    if wx.Platform == '__WXMAC__':
+        return 'open'
+    elif wx.Platform == '__WXMSW__':
+        return 'explorer'
+    else:
+        for cmd in ('nautilus', 'konqueror'):
+            result = os.system("which %s > /dev/null" % cmd)
+            if result == 0:
+                return cmd
+        else:
+            return 'nautilus'
 
 def GetFileName(path):
     """Gets last atom on end of string as filename
     @param path: full path to get filename from
 
     """
-    pieces = os.path.split(path)
-    filename = pieces[-1]
-    return filename
+    return os.path.split(path)[-1]
+
+def GetFileSize(path):
+    """Get the size of the file at a given path
+    @param path: Path to file
+    @return: long
+
+    """
+    try:
+        return os.stat(path)[stat.ST_SIZE]
+    except:
+        return 0
 
 def GetExtension(file_str):
-    """Gets last atom at end of string as extension if 
+    """Gets last atom at end of string as extension if
     no extension whole string is returned
     @param file_str: path or file name to get extension from
 
     """
-    pieces = file_str.split('.')
-    extension = pieces[-1]
-    return extension
+    return file_str.split('.')[-1]
 
 def MakeNewFile(path, name):
     """Make a new file at the given path with the given name.
@@ -407,9 +460,8 @@ def ResolvAbsPath(rel_path):
     @param rel_path: path to construct absolute path for
 
     """
-    path_char = GetPathChar()
     cwd = os.getcwd()
-    pieces = rel_path.split(path_char)
+    pieces = rel_path.split(os.sep)
     cut = 0
 
     for token in pieces:
@@ -417,51 +469,49 @@ def ResolvAbsPath(rel_path):
             cut += 1
 
         if cut > 0:
-            rpath = path_char.join(pieces[cut:])
+            rpath = os.sep.join(pieces[cut:])
             cut *= -1
-            cwd = cwd.split(path_char)
-            apath = path_char.join(cwd[0:cut])
+            cwd = cwd.split(os.sep)
+            apath = os.sep.join(cwd[0:cut])
         else:
             rpath = rel_path
             apath = cwd
 
-    return apath + path_char + rpath
+    return apath + os.sep + rpath
 
 def HasConfigDir(loc=u""):
-    """ Checks if the user has a config directory and returns True 
+    """ Checks if the user has a config directory and returns True
     if the config directory exists or False if it does not.
     @return: whether config dir in question exists on an expected path
 
     """
-    pchar = GetPathChar()
-    if os.path.exists(u"%s%s.%s%s%s" % (wx.GetHomeDir(), pchar,
-                                        ed_glob.PROG_NAME, pchar, loc)):
+    if os.path.exists(u"%s%s.%s%s%s" % (wx.GetHomeDir(), os.sep,
+                                        ed_glob.PROG_NAME, os.sep, loc)):
         return True
     else:
         return False
 
 def MakeConfigDir(name):
-    """Makes a user config direcotry
+    """Makes a user config directory
     @param name: name of config directory to make in user config dir
 
     """
-    config_dir = wx.GetHomeDir() + GetPathChar() + u"." + ed_glob.PROG_NAME
+    config_dir = wx.GetHomeDir() + os.sep + u"." + ed_glob.PROG_NAME
     try:
-        os.mkdir(config_dir + GetPathChar() + name)
+        os.mkdir(config_dir + os.sep + name)
     except (OSError, IOError):
         pass
 
 def CreateConfigDir():
-    """ Creates the user config directory its default sub 
+    """ Creates the user config directory its default sub
     directories and any of the default config files.
     @postcondition: all default configuration files/folders are created
 
     """
     #---- Resolve Paths ----#
-    pchar = GetPathChar()
-    config_dir = u"%s%s.%s" % (wx.GetHomeDir(), pchar, ed_glob.PROG_NAME)
-    profile_dir = u"%s%sprofiles" % (config_dir, pchar)
-    dest_file = u"%s%sdefault.ppb" % (profile_dir, pchar)
+    config_dir = u"%s%s.%s" % (wx.GetHomeDir(), os.sep, ed_glob.PROG_NAME)
+    profile_dir = u"%s%sprofiles" % (config_dir, os.sep)
+    dest_file = u"%s%sdefault.ppb" % (profile_dir, os.sep)
     ext_cfg = ["cache", "styles", "plugins"]
 
     #---- Create Directories ----#
@@ -482,9 +532,9 @@ def CreateConfigDir():
 
 def ResolvConfigDir(config_dir, sys_only=False):
     """Checks for a user config directory and if it is not
-    found it then resolves the absolute path of the executables 
-    directory from the relative execution path. This is then used 
-    to find the location of the specified directory as it relates 
+    found it then resolves the absolute path of the executables
+    directory from the relative execution path. This is then used
+    to find the location of the specified directory as it relates
     to the executable directory, and returns that path as a
     string.
     @param config_dir: name of config directory to resolve
@@ -493,21 +543,20 @@ def ResolvConfigDir(config_dir, sys_only=False):
            the code has proven itself.
 
     """
-    path_char = GetPathChar()
     if not sys_only:
         # Try to look for a user dir
-        user_config = u"%s%s.%s%s%s" % (wx.GetHomeDir(), path_char,
-                                        ed_glob.PROG_NAME, path_char, 
+        user_config = u"%s%s.%s%s%s" % (wx.GetHomeDir(), os.sep,
+                                        ed_glob.PROG_NAME, os.sep,
                                         config_dir)
         if os.path.exists(user_config):
-            return user_config + path_char
+            return user_config + os.sep
 
     # The following lines are used only when Editra is being run as a
     # source package. If the found path does not exist then Editra is
     # running as as a built package.
     path = __file__
-    path = path_char.join(path.split(path_char)[:-2])
-    path =  path + path_char + config_dir + path_char
+    path = os.sep.join(path.split(os.sep)[:-2])
+    path =  path + os.sep + config_dir + os.sep
     if os.path.exists(path):
         return path
 
@@ -520,41 +569,41 @@ def ResolvConfigDir(config_dir, sys_only=False):
         path = os.path.realpath(path)
 
     # Tokenize path
-    pieces = path.split(path_char)
+    pieces = path.split(os.sep)
 
     if os.sys.platform == 'win32':
         # On Windows the exe is in same dir as config directories
-        pro_path = path_char.join(pieces[:-1])
+        pro_path = os.sep.join(pieces[:-1])
 
         if os.path.isabs(pro_path):
             pass
         elif pro_path == "":
             pro_path = os.getcwd()
-            pieces = pro_path.split(path_char)
-            pro_path = path_char.join(pieces[:-1])
+            pieces = pro_path.split(os.sep)
+            pro_path = os.sep.join(pieces[:-1])
         else:
             pro_path = ResolvAbsPath(pro_path)
     else:
-        pro_path = path_char.join(pieces[:-2])
+        pro_path = os.sep.join(pieces[:-2])
 
-        if pro_path.startswith(path_char):
+        if pro_path.startswith(os.sep):
             pass
         elif pro_path == "":
             pro_path = os.getcwd()
-            pieces = pro_path.split(path_char)
+            pieces = pro_path.split(os.sep)
             if pieces[-1] not in [ed_glob.PROG_NAME.lower(), ed_glob.PROG_NAME]:
-                pro_path = path_char.join(pieces[:-1])
+                pro_path = os.sep.join(pieces[:-1])
         else:
             pro_path = ResolvAbsPath(pro_path)
 
     if os.sys.platform == "darwin":
         # On OS X the config directories are in the applet under Resources
-        pro_path = u"%s%sResources%s%s%s" % (pro_path, path_char, path_char,
-                                             config_dir, path_char)
+        pro_path = u"%s%sResources%s%s%s" % (pro_path, os.sep, os.sep,
+                                             config_dir, os.sep)
     else:
-        pro_path = pro_path + path_char + config_dir + path_char
+        pro_path = pro_path + os.sep + config_dir + os.sep
 
-    return os.path.normpath(pro_path) + path_char
+    return os.path.normpath(pro_path) + os.sep
 
 def GetResources(resource):
     """Returns a list of resource directories from a given toplevel config dir
@@ -581,7 +630,7 @@ def GetResourceFiles(resource, trim=True, get_all=False):
     @param resource: name of config directory
     @keyword trim: trim file extensions or not
     @keyword get_all: get a set of both system/user files or just user level
-    
+
 
     """
     rec_dir = ResolvConfigDir(resource)
@@ -669,7 +718,7 @@ def HexToRGB(hex_str):
     """Returns a list of red/green/blue values from a
     hex string.
     @param hex_str: hex string to convert to rgb
-    
+
     """
     hexval = hex_str
     if hexval[0] == u"#":
@@ -727,7 +776,7 @@ class IntValidator(wx.PyValidator):
         @param win: window to validate
 
         """
-        val = win.GetValue()      
+        val = win.GetValue()
         return val.isdigit()
 
     def OnChar(self, event):
